@@ -1,18 +1,5 @@
-// ======================================================================== //
-// Copyright 2009-2020 Intel Corporation                                    //
-//                                                                          //
-// Licensed under the Apache License, Version 2.0 (the "License");          //
-// you may not use this file except in compliance with the License.         //
-// You may obtain a copy of the License at                                  //
-//                                                                          //
-//     http://www.apache.org/licenses/LICENSE-2.0                           //
-//                                                                          //
-// Unless required by applicable law or agreed to in writing, software      //
-// distributed under the License is distributed on an "AS IS" BASIS,        //
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. //
-// See the License for the specific language governing permissions and      //
-// limitations under the License.                                           //
-// ======================================================================== //
+// Copyright 2009-2020 Intel Corporation
+// SPDX-License-Identifier: Apache-2.0
 
 #pragma once
 
@@ -87,7 +74,7 @@ namespace embree
         return r0.size() < r1.size();
       }
 	
-      friend std::ostream& operator<<(std::ostream& cout, const range& r) {
+      friend embree_ostream operator<<(embree_ostream cout, const range& r) {
         return cout << "range [" << r.begin() << ", " << r.end() << "]";
       }
       
@@ -141,7 +128,7 @@ namespace embree
         _ext_end += plus;
       }
 
-      friend std::ostream& operator<<(std::ostream& cout, const extended_range& r) {
+      friend embree_ostream operator<<(embree_ostream cout, const extended_range& r) {
         return cout << "extended_range [" << r.begin() << ", " << r.end() <<  " (" << r.ext_end() << ")]";
       }
       
