@@ -1,18 +1,5 @@
-// ======================================================================== //
-// Copyright 2009-2018 Intel Corporation                                    //
-//                                                                          //
-// Licensed under the Apache License, Version 2.0 (the "License");          //
-// you may not use this file except in compliance with the License.         //
-// You may obtain a copy of the License at                                  //
-//                                                                          //
-//     http://www.apache.org/licenses/LICENSE-2.0                           //
-//                                                                          //
-// Unless required by applicable law or agreed to in writing, software      //
-// distributed under the License is distributed on an "AS IS" BASIS,        //
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. //
-// See the License for the specific language governing permissions and      //
-// limitations under the License.                                           //
-// ======================================================================== //
+// Copyright 2009-2020 Intel Corporation
+// SPDX-License-Identifier: Apache-2.0
 
 #pragma once
 
@@ -22,6 +9,8 @@ namespace embree
   template<>
   struct vdouble<8>
   {
+    ALIGNED_STRUCT_(64);
+    
     typedef vboold8 Bool;
 
     enum  { size = 8 }; // number of SIMD elements
@@ -357,7 +346,7 @@ namespace embree
   /// Output Operators
   ////////////////////////////////////////////////////////////////////////////////
 
-  __forceinline std::ostream& operator <<(std::ostream& cout, const vdouble8& v)
+  __forceinline embree_ostream operator <<(embree_ostream cout, const vdouble8& v)
   {
     cout << "<" << v[0];
     for (size_t i=1; i<8; i++) cout << ", " << v[i];
