@@ -1,25 +1,17 @@
-// ======================================================================== //
-// Copyright 2009-2020 Intel Corporation                                    //
-//                                                                          //
-// Licensed under the Apache License, Version 2.0 (the "License");          //
-// you may not use this file except in compliance with the License.         //
-// You may obtain a copy of the License at                                  //
-//                                                                          //
-//     http://www.apache.org/licenses/LICENSE-2.0                           //
-//                                                                          //
-// Unless required by applicable law or agreed to in writing, software      //
-// distributed under the License is distributed on an "AS IS" BASIS,        //
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. //
-// See the License for the specific language governing permissions and      //
-// limitations under the License.                                           //
-// ======================================================================== //
+// Copyright 2009-2020 Intel Corporation
+// SPDX-License-Identifier: Apache-2.0
 
 #include "taskschedulertbb.h"
 
 namespace embree
 {
   static bool g_tbb_threads_initialized = false;
+
+#if TBB_INTERFACE_VERSION >= 11005
+  static tbb::global_control* g_tbb_thread_control = nullptr;
+#else
   static tbb::task_scheduler_init g_tbb_threads(tbb::task_scheduler_init::deferred);
+#endif
   
   class TBBAffinity: public tbb::task_scheduler_observer
   {
@@ -37,7 +29,12 @@ namespace embree
 
     /* first terminate threads in case we configured them */
     if (g_tbb_threads_initialized) {
+#if TBB_INTERFACE_VERSION >= 11005
+      delete g_tbb_thread_control;
+      g_tbb_thread_control = nullptr;
+#else
       g_tbb_threads.terminate();
+#endif
       g_tbb_threads_initialized = false;
     }
     
@@ -49,14 +46,17 @@ namespace embree
     
     /* now either keep default settings or configure number of threads */
     if (numThreads == std::numeric_limits<size_t>::max()) {
-      g_tbb_threads_initialized = false;
       numThreads = threadCount();
-      //numThreads = tbb::task_scheduler_init::default_num_threads();
-    } else {
+    }
+    else {
       g_tbb_threads_initialized = true;
       const size_t max_concurrency = threadCount();
       if (numThreads > max_concurrency) numThreads = max_concurrency;
+#if TBB_INTERFACE_VERSION >= 11005
+      g_tbb_thread_control = new tbb::global_control(tbb::global_control::max_allowed_parallelism,numThreads);
+#else
       g_tbb_threads.initialize(int(numThreads));
+#endif
     }
 
     /* start worker threads */
@@ -72,7 +72,12 @@ namespace embree
   void TaskScheduler::destroy()
   {
     if (g_tbb_threads_initialized) {
+#if TBB_INTERFACE_VERSION >= 11005
+      delete g_tbb_thread_control;
+      g_tbb_thread_control = nullptr;
+#else
       g_tbb_threads.terminate();
+#endif
       g_tbb_threads_initialized = false;
     }
   }
