@@ -1,18 +1,5 @@
-// ======================================================================== //
-// Copyright 2009-2020 Intel Corporation                                    //
-//                                                                          //
-// Licensed under the Apache License, Version 2.0 (the "License");          //
-// you may not use this file except in compliance with the License.         //
-// You may obtain a copy of the License at                                  //
-//                                                                          //
-//     http://www.apache.org/licenses/LICENSE-2.0                           //
-//                                                                          //
-// Unless required by applicable law or agreed to in writing, software      //
-// distributed under the License is distributed on an "AS IS" BASIS,        //
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. //
-// See the License for the specific language governing permissions and      //
-// limitations under the License.                                           //
-// ======================================================================== //
+// Copyright 2009-2020 Intel Corporation
+// SPDX-License-Identifier: Apache-2.0
 
 #pragma once
 
@@ -67,10 +54,10 @@ namespace embree
       template<typename NodeRef,
         typename RecalculatePrimRef,
         typename CreateAllocFunc,
-        typename CreateAlignedNodeMBFunc,
-        typename SetAlignedNodeMBFunc,
-        typename CreateUnalignedNodeMBFunc,
-        typename SetUnalignedNodeMBFunc,
+        typename CreateAABBNodeMBFunc,
+        typename SetAABBNodeMBFunc,
+        typename CreateOBBNodeMBFunc,
+        typename SetOBBNodeMBFunc,
         typename CreateLeafFunc,
         typename ProgressMonitor>
 
@@ -97,10 +84,10 @@ namespace embree
           BuilderT (Scene* scene,
                     const RecalculatePrimRef& recalculatePrimRef,
                     const CreateAllocFunc& createAlloc,
-                    const CreateAlignedNodeMBFunc& createAlignedNodeMB,
-                    const SetAlignedNodeMBFunc& setAlignedNodeMB,
-                    const CreateUnalignedNodeMBFunc& createUnalignedNodeMB,
-                    const SetUnalignedNodeMBFunc& setUnalignedNodeMB,
+                    const CreateAABBNodeMBFunc& createAABBNodeMB,
+                    const SetAABBNodeMBFunc& setAABBNodeMB,
+                    const CreateOBBNodeMBFunc& createOBBNodeMB,
+                    const SetOBBNodeMBFunc& setOBBNodeMB,
                     const CreateLeafFunc& createLeaf,
                     const ProgressMonitor& progressMonitor,
                     const Settings settings)
@@ -109,8 +96,8 @@ namespace embree
             scene(scene),
             recalculatePrimRef(recalculatePrimRef),
             createAlloc(createAlloc),
-            createAlignedNodeMB(createAlignedNodeMB), setAlignedNodeMB(setAlignedNodeMB),
-            createUnalignedNodeMB(createUnalignedNodeMB), setUnalignedNodeMB(setUnalignedNodeMB),
+            createAABBNodeMB(createAABBNodeMB), setAABBNodeMB(setAABBNodeMB),
+            createOBBNodeMB(createOBBNodeMB), setOBBNodeMB(setOBBNodeMB),
             createLeaf(createLeaf),
             progressMonitor(progressMonitor),
             unalignedHeuristic(scene),
@@ -195,6 +182,7 @@ namespace embree
 
             /* fill all children by always splitting the largest one */
             LocalChildList children(current);
+            NodeRecordMB4D values[MAX_BRANCHING_FACTOR];
 
             do {
 
@@ -239,15 +227,16 @@ namespace embree
             }
             
             /* create node */
-            NodeRef node = createAlignedNodeMB(alloc,timesplit);
+            NodeRef node = createAABBNodeMB(children.children.data(),children.numChildren,alloc,timesplit);
 
             LBBox3fa bounds = empty;
             for (size_t i=0; i<children.size(); i++) {
-              const auto child = createLargeLeaf(children[i],alloc);
-              setAlignedNodeMB(node,i,child);
-              bounds.extend(child.lbounds);
+              values[i] = createLargeLeaf(children[i],alloc);
+              bounds.extend(values[i].lbounds);
             }
 
+            setAABBNodeMB(current,children.children.data(),node,values,children.numChildren);
+
             if (timesplit)
               bounds = current.prims.linearBounds(recalculatePrimRef);
               
@@ -332,6 +321,7 @@ namespace embree
             }
 
             /* fill all children by always splitting the one with the largest surface area */
+            NodeRecordMB4D values[MAX_BRANCHING_FACTOR];
             LocalChildList children(current);
             bool aligned = true;
             bool timesplit = false;
@@ -374,15 +364,14 @@ namespace embree
             /* create time split node */
             if (timesplit)
             {
-              const NodeRef node = createAlignedNodeMB(alloc,true);
+              const NodeRef node = createAABBNodeMB(children.children.data(),children.numChildren,alloc,true);
 
               /* spawn tasks or ... */
               if (current.size() > SINGLE_THREADED_THRESHOLD)
               {
                 parallel_for(size_t(0), children.size(), [&] (const range<size_t>& r) {
                     for (size_t i=r.begin(); i<r.end(); i++) {
-                      const auto child = recurse(children[i],nullptr,true);
-                      setAlignedNodeMB(node,i,child);
+                      values[i] = recurse(children[i],nullptr,true);
                       _mm_mfence(); // to allow non-temporal stores during build
                     }
                   });
@@ -390,11 +379,12 @@ namespace embree
               /* ... continue sequential */
               else {
                 for (size_t i=0; i<children.size(); i++) {
-                  const auto child = recurse(children[i],alloc,false);
-                  setAlignedNodeMB(node,i,child);
+                  values[i] = recurse(children[i],alloc,false);
                 }
               }
 
+              setAABBNodeMB(current,children.children.data(),node,values,children.numChildren);
+
               const LBBox3fa bounds = current.prims.linearBounds(recalculatePrimRef);
               return NodeRecordMB4D(node,bounds,current.prims.time_range);
             }
@@ -402,7 +392,7 @@ namespace embree
             /* create aligned node */
             else if (aligned)
             {
-              const NodeRef node = createAlignedNodeMB(alloc,false);
+              const NodeRef node = createAABBNodeMB(children.children.data(),children.numChildren,alloc,true);
 
               /* spawn tasks or ... */
               if (current.size() > SINGLE_THREADED_THRESHOLD)
@@ -410,9 +400,8 @@ namespace embree
                 LBBox3fa cbounds[MAX_BRANCHING_FACTOR];
                 parallel_for(size_t(0), children.size(), [&] (const range<size_t>& r) {
                     for (size_t i=r.begin(); i<r.end(); i++) {
-                      const auto child = recurse(children[i],nullptr,true);
-                      setAlignedNodeMB(node,i,child);
-                      cbounds[i] = child.lbounds;
+                      values[i] = recurse(children[i],nullptr,true);
+                      cbounds[i] = values[i].lbounds;
                       _mm_mfence(); // to allow non-temporal stores during build
                     }
                   });
@@ -420,7 +409,7 @@ namespace embree
                 LBBox3fa bounds = empty;
                 for (size_t i=0; i<children.size(); i++)
                   bounds.extend(cbounds[i]);
-
+                setAABBNodeMB(current,children.children.data(),node,values,children.numChildren);
                 return NodeRecordMB4D(node,bounds,current.prims.time_range);
               }
               /* ... continue sequentially */
@@ -428,10 +417,10 @@ namespace embree
               {
                 LBBox3fa bounds = empty;
                 for (size_t i=0; i<children.size(); i++) {
-                  const auto child = recurse(children[i],alloc,false);
-                  setAlignedNodeMB(node,i,child);
-                  bounds.extend(child.lbounds);
+                  values[i] = recurse(children[i],alloc,false);
+                  bounds.extend(values[i].lbounds);
                 }
+                setAABBNodeMB(current,children.children.data(),node,values,children.numChildren);
                 return NodeRecordMB4D(node,bounds,current.prims.time_range);
               }
             }
@@ -439,7 +428,7 @@ namespace embree
             /* create unaligned node */
             else
             {
-              const NodeRef node = createUnalignedNodeMB(alloc);
+              const NodeRef node = createOBBNodeMB(alloc);
 
               /* spawn tasks or ... */
               if (current.size() > SINGLE_THREADED_THRESHOLD)
@@ -449,7 +438,7 @@ namespace embree
                       const LinearSpace3fa space = unalignedHeuristic.computeAlignedSpaceMB(scene,children[i].prims);
                       const LBBox3fa lbounds = children[i].prims.linearBounds(recalculatePrimRef,space);
                       const auto child = recurse(children[i],nullptr,true);
-                      setUnalignedNodeMB(node,i,child.ref,space,lbounds,children[i].prims.time_range);
+                      setOBBNodeMB(node,i,child.ref,space,lbounds,children[i].prims.time_range);
                       _mm_mfence(); // to allow non-temporal stores during build
                     }
                   });
@@ -461,7 +450,7 @@ namespace embree
                   const LinearSpace3fa space = unalignedHeuristic.computeAlignedSpaceMB(scene,children[i].prims);
                   const LBBox3fa lbounds = children[i].prims.linearBounds(recalculatePrimRef,space);
                   const auto child = recurse(children[i],alloc,false);
-                  setUnalignedNodeMB(node,i,child.ref,space,lbounds,children[i].prims.time_range);
+                  setOBBNodeMB(node,i,child.ref,space,lbounds,children[i].prims.time_range);
                 }
               }
 
@@ -486,10 +475,10 @@ namespace embree
           Scene* scene;
           const RecalculatePrimRef& recalculatePrimRef;
           const CreateAllocFunc& createAlloc;
-          const CreateAlignedNodeMBFunc& createAlignedNodeMB;
-          const SetAlignedNodeMBFunc& setAlignedNodeMB;
-          const CreateUnalignedNodeMBFunc& createUnalignedNodeMB;
-          const SetUnalignedNodeMBFunc& setUnalignedNodeMB;
+          const CreateAABBNodeMBFunc& createAABBNodeMB;
+          const SetAABBNodeMBFunc& setAABBNodeMB;
+          const CreateOBBNodeMBFunc& createOBBNodeMB;
+          const SetOBBNodeMBFunc& setOBBNodeMB;
           const CreateLeafFunc& createLeaf;
           const ProgressMonitor& progressMonitor;
 
@@ -502,32 +491,32 @@ namespace embree
       template<typename NodeRef,
         typename RecalculatePrimRef,
         typename CreateAllocFunc,
-        typename CreateAlignedNodeMBFunc,
-        typename SetAlignedNodeMBFunc,
-        typename CreateUnalignedNodeMBFunc,
-        typename SetUnalignedNodeMBFunc,
+        typename CreateAABBNodeMBFunc,
+        typename SetAABBNodeMBFunc,
+        typename CreateOBBNodeMBFunc,
+        typename SetOBBNodeMBFunc,
         typename CreateLeafFunc,
         typename ProgressMonitor>
 
         static BVHNodeRecordMB4D<NodeRef> build (Scene* scene, mvector<PrimRefMB>& prims, const PrimInfoMB& pinfo,
                                                const RecalculatePrimRef& recalculatePrimRef,
                                                const CreateAllocFunc& createAlloc,
-                                               const CreateAlignedNodeMBFunc& createAlignedNodeMB,
-                                               const SetAlignedNodeMBFunc& setAlignedNodeMB,
-                                               const CreateUnalignedNodeMBFunc& createUnalignedNodeMB,
-                                               const SetUnalignedNodeMBFunc& setUnalignedNodeMB,
+                                               const CreateAABBNodeMBFunc& createAABBNodeMB,
+                                               const SetAABBNodeMBFunc& setAABBNodeMB,
+                                               const CreateOBBNodeMBFunc& createOBBNodeMB,
+                                               const SetOBBNodeMBFunc& setOBBNodeMB,
                                                const CreateLeafFunc& createLeaf,
                                                const ProgressMonitor& progressMonitor,
                                                const Settings settings)
         {
           typedef BuilderT<NodeRef,RecalculatePrimRef,CreateAllocFunc,
-            CreateAlignedNodeMBFunc,SetAlignedNodeMBFunc,
-            CreateUnalignedNodeMBFunc,SetUnalignedNodeMBFunc,
+            CreateAABBNodeMBFunc,SetAABBNodeMBFunc,
+            CreateOBBNodeMBFunc,SetOBBNodeMBFunc,
             CreateLeafFunc,ProgressMonitor> Builder;
 
           Builder builder(scene,recalculatePrimRef,createAlloc,
-                          createAlignedNodeMB,setAlignedNodeMB,
-                          createUnalignedNodeMB,setUnalignedNodeMB,
+                          createAABBNodeMB,setAABBNodeMB,
+                          createOBBNodeMB,setOBBNodeMB,
                           createLeaf,progressMonitor,settings);
 
           return builder(prims,pinfo);
