@@ -1,18 +1,5 @@
-// ======================================================================== //
-// Copyright 2009-2020 Intel Corporation                                    //
-//                                                                          //
-// Licensed under the Apache License, Version 2.0 (the "License");          //
-// you may not use this file except in compliance with the License.         //
-// You may obtain a copy of the License at                                  //
-//                                                                          //
-//     http://www.apache.org/licenses/LICENSE-2.0                           //
-//                                                                          //
-// Unless required by applicable law or agreed to in writing, software      //
-// distributed under the License is distributed on an "AS IS" BASIS,        //
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. //
-// See the License for the specific language governing permissions and      //
-// limitations under the License.                                           //
-// ======================================================================== //
+// Copyright 2009-2020 Intel Corporation
+// SPDX-License-Identifier: Apache-2.0
 
 #pragma once
 
@@ -115,7 +102,7 @@ namespace embree
         }
         
         /*! stream output */
-        friend std::ostream& operator<<(std::ostream& cout, const BinMapping& mapping) {
+        friend embree_ostream operator<<(embree_ostream cout, const BinMapping& mapping) {
           return cout << "BinMapping { num = " << mapping.num << ", ofs = " << mapping.ofs << ", scale = " << mapping.scale << "}";
         }
         
@@ -155,7 +142,7 @@ namespace embree
         __forceinline float splitSAH() const { return sah; }
         
         /*! stream output */
-        friend std::ostream& operator<<(std::ostream& cout, const BinSplit& split) {
+        friend embree_ostream operator<<(embree_ostream cout, const BinSplit& split) {
           return cout << "BinSplit { sah = " << split.sah << ", dim = " << split.dim << ", pos = " << split.pos << "}";
         }
         
