@@ -1,18 +1,5 @@
-// ======================================================================== //
-// Copyright 2009-2020 Intel Corporation                                    //
-//                                                                          //
-// Licensed under the Apache License, Version 2.0 (the "License");          //
-// you may not use this file except in compliance with the License.         //
-// You may obtain a copy of the License at                                  //
-//                                                                          //
-//     http://www.apache.org/licenses/LICENSE-2.0                           //
-//                                                                          //
-// Unless required by applicable law or agreed to in writing, software      //
-// distributed under the License is distributed on an "AS IS" BASIS,        //
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. //
-// See the License for the specific language governing permissions and      //
-// limitations under the License.                                           //
-// ======================================================================== //
+// Copyright 2009-2020 Intel Corporation
+// SPDX-License-Identifier: Apache-2.0
 
 #pragma once
 
@@ -161,7 +148,7 @@ namespace embree
       }
       
       /*! stream output */
-      friend std::ostream& operator<<(std::ostream& cout, const PrimInfoT& pinfo) {
+      friend embree_ostream operator<<(embree_ostream cout, const PrimInfoT& pinfo) {
 	return cout << "PrimInfo { begin = " << pinfo.begin << ", end = " << pinfo.end << ", geomBounds = " << pinfo.geomBounds << ", centBounds = " << pinfo.centBounds << "}";
       }
       
@@ -253,7 +240,7 @@ namespace embree
       }
       
       /*! stream output */
-      friend std::ostream& operator<<(std::ostream& cout, const PrimInfoMBT& pinfo) 
+      friend embree_ostream operator<<(embree_ostream cout, const PrimInfoMBT& pinfo) 
       {
 	return cout << "PrimInfo { " << 
           "object_range = " << pinfo.object_range << 
