@@ -1,18 +1,5 @@
-// ======================================================================== //
-// Copyright 2009-2020 Intel Corporation                                    //
-//                                                                          //
-// Licensed under the Apache License, Version 2.0 (the "License");          //
-// you may not use this file except in compliance with the License.         //
-// You may obtain a copy of the License at                                  //
-//                                                                          //
-//     http://www.apache.org/licenses/LICENSE-2.0                           //
-//                                                                          //
-// Unless required by applicable law or agreed to in writing, software      //
-// distributed under the License is distributed on an "AS IS" BASIS,        //
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. //
-// See the License for the specific language governing permissions and      //
-// limitations under the License.                                           //
-// ======================================================================== //
+// Copyright 2009-2020 Intel Corporation
+// SPDX-License-Identifier: Apache-2.0
 
 #pragma once
 
@@ -104,7 +91,7 @@ namespace embree
         Vec3ia iupper(floor(gupper));
 
         /* this ignores dimensions that are empty */
-        iupper = (__m128i)select(vint4(glower) >= vint4(gupper),vint4(ilower),vint4(iupper));
+        iupper = (Vec3ia)(select(vint4(glower) >= vint4(gupper),vint4(ilower),vint4(iupper)));
 
         /* compute a morton code for the lower and upper grid coordinates. */
         const unsigned int lower_code = bitInterleave(ilower.x,ilower.y,ilower.z);
@@ -179,7 +166,7 @@ namespace embree
       Vec3ia iupper(floor(gupper));
       
       /* this ignores dimensions that are empty */
-      iupper = (__m128i)select(vint4(glower) >= vint4(gupper),vint4(ilower),vint4(iupper));
+      iupper = (Vec3ia)select(vint4(glower) >= vint4(gupper),vint4(ilower),vint4(iupper));
 
       /* compute a morton code for the lower and upper grid coordinates. */
       const unsigned int lower_code = bitInterleave(ilower.x,ilower.y,ilower.z);
