@@ -1,18 +1,5 @@
-// ======================================================================== //
-// Copyright 2009-2020 Intel Corporation                                    //
-//                                                                          //
-// Licensed under the Apache License, Version 2.0 (the "License");          //
-// you may not use this file except in compliance with the License.         //
-// You may obtain a copy of the License at                                  //
-//                                                                          //
-//     http://www.apache.org/licenses/LICENSE-2.0                           //
-//                                                                          //
-// Unless required by applicable law or agreed to in writing, software      //
-// distributed under the License is distributed on an "AS IS" BASIS,        //
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. //
-// See the License for the specific language governing permissions and      //
-// limitations under the License.                                           //
-// ======================================================================== //
+// Copyright 2009-2020 Intel Corporation
+// SPDX-License-Identifier: Apache-2.0
 
 #include "bvh.h"
 #include "../builders/bvh_builder_sah.h"
@@ -94,7 +81,7 @@ namespace embree
       struct BVHNBuilderMblurVirtual
       {
         typedef BVHN<N> BVH;
-        typedef typename BVH::AlignedNodeMB AlignedNodeMB;
+        typedef typename BVH::AABBNodeMB AABBNodeMB;
         typedef typename BVH::NodeRef NodeRef;
         typedef typename BVH::NodeRecordMB NodeRecordMB;
         typedef FastAllocator::CachedAllocator Allocator;
