@@ -1,18 +1,5 @@
-// ======================================================================== //
-// Copyright 2009-2020 Intel Corporation                                    //
-//                                                                          //
-// Licensed under the Apache License, Version 2.0 (the "License");          //
-// you may not use this file except in compliance with the License.         //
-// You may obtain a copy of the License at                                  //
-//                                                                          //
-//     http://www.apache.org/licenses/LICENSE-2.0                           //
-//                                                                          //
-// Unless required by applicable law or agreed to in writing, software      //
-// distributed under the License is distributed on an "AS IS" BASIS,        //
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. //
-// See the License for the specific language governing permissions and      //
-// limitations under the License.                                           //
-// ======================================================================== //
+// Copyright 2009-2020 Intel Corporation
+// SPDX-License-Identifier: Apache-2.0
 
 #pragma once
 
@@ -36,8 +23,8 @@ namespace embree
       typedef BVHN<N> BVH;
       typedef typename BVH::NodeRef NodeRef;
       typedef typename BVH::BaseNode BaseNode;
-      typedef typename BVH::AlignedNode AlignedNode;
-      typedef typename BVH::AlignedNodeMB AlignedNodeMB;
+      typedef typename BVH::AABBNode AABBNode;
+      typedef typename BVH::AABBNodeMB AABBNodeMB;
 
       template<int K>
       __forceinline static size_t initPacketsAndFrustum(RayK<K>** inputPackets, size_t numOctantRays,
@@ -117,9 +104,9 @@ namespace embree
       }
 
       template<int K>
-      __forceinline static size_t intersectAlignedNodePacket(size_t m_active,
+      __forceinline static size_t intersectAABBNodePacket(size_t m_active,
                                                              const TravRayKStream<K,robust>* packets,
-                                                             const AlignedNode* __restrict__ node,
+                                                             const AABBNode* __restrict__ node,
                                                              size_t boxID,
                                                              const NearFarPrecalculations& nf)
       {
@@ -138,7 +125,7 @@ namespace embree
       template<int K>
       __forceinline static size_t traverseCoherentStream(size_t m_active,
                                                          TravRayKStream<K, robust>* packets,
-                                                         const AlignedNode* __restrict__ node,
+                                                         const AABBNode* __restrict__ node,
                                                          const Frustum<robust>& frustum,
                                                          size_t* maskK,
                                                          vfloat<Nx>& dist)
@@ -154,7 +141,7 @@ namespace embree
         while (unlikely(m_node))
         {
           const size_t boxID = bscf(m_node);
-          const size_t m_current = m_active & intersectAlignedNodePacket(m_active, packets, node, boxID, frustum.nf);
+          const size_t m_current = m_active & intersectAABBNodePacket(m_active, packets, node, boxID, frustum.nf);
           m_node_hit ^= m_current ? (size_t)0 : ((size_t)1 << boxID);
           maskK[boxID] = m_current;
         }
@@ -165,7 +152,7 @@ namespace embree
       template<int K>
       __forceinline static vint<Nx> traverseIncoherentStream(size_t m_active,
                                                              TravRayKStreamFast<K>* __restrict__ packets,
-                                                             const AlignedNode* __restrict__ node,
+                                                             const AABBNode* __restrict__ node,
                                                              const NearFarPrecalculations& nf,
                                                              const int shiftTable[32])
       {
@@ -213,7 +200,7 @@ namespace embree
       template<int K>
       __forceinline static vint<Nx> traverseIncoherentStream(size_t m_active,
                                                              TravRayKStreamRobust<K>* __restrict__ packets,
-                                                             const AlignedNode* __restrict__ node,
+                                                             const AABBNode* __restrict__ node,
                                                              const NearFarPrecalculations& nf,
                                                              const int shiftTable[32])
       {
