@@ -1,18 +1,5 @@
-// ======================================================================== //
-// Copyright 2009-2020 Intel Corporation                                    //
-//                                                                          //
-// Licensed under the Apache License, Version 2.0 (the "License");          //
-// you may not use this file except in compliance with the License.         //
-// You may obtain a copy of the License at                                  //
-//                                                                          //
-//     http://www.apache.org/licenses/LICENSE-2.0                           //
-//                                                                          //
-// Unless required by applicable law or agreed to in writing, software      //
-// distributed under the License is distributed on an "AS IS" BASIS,        //
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. //
-// See the License for the specific language governing permissions and      //
-// limitations under the License.                                           //
-// ======================================================================== //
+// Copyright 2009-2020 Intel Corporation
+// SPDX-License-Identifier: Apache-2.0
 
 #include "bvh_rotate.h"
 
@@ -32,7 +19,7 @@ namespace embree
       /*! nothing to rotate if we reached a leaf node. */
       if (parentRef.isBarrier()) return 0;
       if (parentRef.isLeaf()) return 0;
-      AlignedNode* parent = parentRef.alignedNode();
+      AABBNode* parent = parentRef.getAABBNode();
       
       /*! rotate all children first */
       vint4 cdepth;
@@ -59,7 +46,7 @@ namespace embree
 	/*! ignore leaf nodes as we cannot descent into them */
 	if (parent->child(c2).isBarrier()) continue;
 	if (parent->child(c2).isLeaf()) continue;
-	AlignedNode* child2 = parent->child(c2).alignedNode();
+	AABBNode* child2 = parent->child(c2).getAABBNode();
 	
 	/*! transpose child bounds */
 	BBox<vfloat4> child2c0,child2c1,child2c2,child2c3;
@@ -125,11 +112,11 @@ namespace embree
       if (bestChild1 == size_t(-1)) return 1+reduce_max(cdepth);
       
       /*! perform the best found tree rotation */
-      AlignedNode* child2 = parent->child(bestChild2).alignedNode();
-      BVH4::swap(parent,bestChild1,child2,bestChild2Child);
+      AABBNode* child2 = parent->child(bestChild2).getAABBNode();
+      AABBNode::swap(parent,bestChild1,child2,bestChild2Child);
       parent->setBounds(bestChild2,child2->bounds());
-      BVH4::compact(parent);
-      BVH4::compact(child2);
+      AABBNode::compact(parent);
+      AABBNode::compact(child2);
       
       /*! This returned depth is conservative as the child that was
        *  pulled up in the tree could have been on the critical path. */
