@@ -1,18 +1,5 @@
-// ======================================================================== //
-// Copyright 2009-2020 Intel Corporation                                    //
-//                                                                          //
-// Licensed under the Apache License, Version 2.0 (the "License");          //
-// you may not use this file except in compliance with the License.         //
-// You may obtain a copy of the License at                                  //
-//                                                                          //
-//     http://www.apache.org/licenses/LICENSE-2.0                           //
-//                                                                          //
-// Unless required by applicable law or agreed to in writing, software      //
-// distributed under the License is distributed on an "AS IS" BASIS,        //
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. //
-// See the License for the specific language governing permissions and      //
-// limitations under the License.                                           //
-// ======================================================================== //
+// Copyright 2009-2020 Intel Corporation
+// SPDX-License-Identifier: Apache-2.0
 
 #pragma once
 
@@ -86,11 +73,11 @@ namespace embree
     using TravRayKStreamRobust = TravRayKStream<K, true>;
 
     //////////////////////////////////////////////////////////////////////////////////////
-    // Fast AlignedNode intersection
+    // Fast AABBNode intersection
     //////////////////////////////////////////////////////////////////////////////////////
 
     template<int N, int Nx, int K>
-    __forceinline size_t intersectNode1(const typename BVHN<N>::AlignedNode* __restrict__ node,
+    __forceinline size_t intersectNode1(const typename BVHN<N>::AABBNode* __restrict__ node,
                                         const TravRayKStreamFast<K>& ray, size_t k, const NearFarPrecalculations& nf)
     {
       const vfloat<Nx> bminX = vfloat<Nx>(*(const vfloat<N>*)((const char*)&node->lower_x + nf.nearX));
@@ -115,7 +102,7 @@ namespace embree
     }
 
     template<int N, int K>
-    __forceinline size_t intersectNodeK(const typename BVHN<N>::AlignedNode* __restrict__ node, size_t i,
+    __forceinline size_t intersectNodeK(const typename BVHN<N>::AABBNode* __restrict__ node, size_t i,
                                         const TravRayKStreamFast<K>& ray, const NearFarPrecalculations& nf)
     {
       char* ptr = (char*)&node->lower_x + i*sizeof(float);
@@ -142,11 +129,11 @@ namespace embree
     }
 
     //////////////////////////////////////////////////////////////////////////////////////
-    // Robust AlignedNode intersection
+    // Robust AABBNode intersection
     //////////////////////////////////////////////////////////////////////////////////////
 
     template<int N, int Nx, int K>
-    __forceinline size_t intersectNode1(const typename BVHN<N>::AlignedNode* __restrict__ node,
+    __forceinline size_t intersectNode1(const typename BVHN<N>::AABBNode* __restrict__ node,
                                         const TravRayKStreamRobust<K>& ray, size_t k, const NearFarPrecalculations& nf)
     {
       const vfloat<Nx> bminX = vfloat<Nx>(*(const vfloat<N>*)((const char*)&node->lower_x + nf.nearX));
@@ -172,7 +159,7 @@ namespace embree
     }
 
     template<int N, int K>
-    __forceinline size_t intersectNodeK(const typename BVHN<N>::AlignedNode* __restrict__ node, size_t i,
+    __forceinline size_t intersectNodeK(const typename BVHN<N>::AABBNode* __restrict__ node, size_t i,
                                         const TravRayKStreamRobust<K>& ray, const NearFarPrecalculations& nf)
     {
       char *ptr = (char*)&node->lower_x + i*sizeof(float);
