@@ -1,18 +1,5 @@
-// ======================================================================== //
-// Copyright 2009-2020 Intel Corporation                                    //
-//                                                                          //
-// Licensed under the Apache License, Version 2.0 (the "License");          //
-// you may not use this file except in compliance with the License.         //
-// You may obtain a copy of the License at                                  //
-//                                                                          //
-//     http://www.apache.org/licenses/LICENSE-2.0                           //
-//                                                                          //
-// Unless required by applicable law or agreed to in writing, software      //
-// distributed under the License is distributed on an "AS IS" BASIS,        //
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. //
-// See the License for the specific language governing permissions and      //
-// limitations under the License.                                           //
-// ======================================================================== //
+// Copyright 2009-2020 Intel Corporation
+// SPDX-License-Identifier: Apache-2.0
 
 #pragma once
 
@@ -188,13 +175,13 @@ namespace embree
 
     /* Calculates if this is a valid ray that does not cause issues during traversal */
     __forceinline bool valid() const {
-      return all(le_mask(abs(Vec3fa(org,0.0f)), Vec3fa(FLT_LARGE)) & le_mask(abs(Vec3fa(dir,0.0f)), Vec3fa(FLT_LARGE))) && abs(tnear()) <= float(inf) && abs(tfar) <= float(inf);
+      return all(le_mask(abs(Vec3fa(org)), Vec3fa(FLT_LARGE)) & le_mask(abs(Vec3fa(dir)), Vec3fa(FLT_LARGE))) && abs(tnear()) <= float(inf) && abs(tfar) <= float(inf);
     }
 
     /* Ray data */
-    Vec3fa org;  // 3 floats for ray origin, 1 float for tnear
+    Vec3ff org;  // 3 floats for ray origin, 1 float for tnear
     //float tnear; // start of ray segment
-    Vec3fa dir;  // 3 floats for ray direction, 1 float for time
+    Vec3ff dir;  // 3 floats for ray direction, 1 float for time
     // float time; 
     float tfar;  // end of ray segment
     int mask;    // used to mask out objects during traversal
@@ -405,43 +392,43 @@ namespace embree
 
   /* Outputs ray to stream */
   template<int K>
-  inline std::ostream& operator <<(std::ostream& cout, const RayK<K>& ray)
+  __forceinline embree_ostream operator <<(embree_ostream cout, const RayK<K>& ray)
   {
-    return cout << "{ " << std::endl
-                << "  org = " << ray.org << std::endl
-                << "  dir = " << ray.dir << std::endl
-                << "  near = " << ray.tnear() << std::endl
-                << "  far = " << ray.tfar << std::endl
-                << "  time = " << ray.time() << std::endl
-                << "  mask = " << ray.mask << std::endl
-                << "  id = " << ray.id << std::endl
-                << "  flags = " << ray.flags << std::endl
+    return cout << "{ " << embree_endl
+                << "  org = " << ray.org << embree_endl
+                << "  dir = " << ray.dir << embree_endl
+                << "  near = " << ray.tnear() << embree_endl
+                << "  far = " << ray.tfar << embree_endl
+                << "  time = " << ray.time() << embree_endl
+                << "  mask = " << ray.mask << embree_endl
+                << "  id = " << ray.id << embree_endl
+                << "  flags = " << ray.flags << embree_endl
                 << "}";
   }
 
   template<int K>
-  inline std::ostream& operator <<(std::ostream& cout, const RayHitK<K>& ray)
+  __forceinline embree_ostream operator <<(embree_ostream cout, const RayHitK<K>& ray)
   {
-    cout << "{ " << std::endl
-         << "  org = " << ray.org << std::endl
-         << "  dir = " << ray.dir << std::endl
-         << "  near = " << ray.tnear() << std::endl
-         << "  far = " << ray.tfar << std::endl
-         << "  time = " << ray.time() << std::endl
-         << "  mask = " << ray.mask << std::endl
-         << "  id = " << ray.id << std::endl
-         << "  flags = " << ray.flags << std::endl
+    cout << "{ " << embree_endl
+         << "  org = " << ray.org << embree_endl
+         << "  dir = " << ray.dir << embree_endl
+         << "  near = " << ray.tnear() << embree_endl
+         << "  far = " << ray.tfar << embree_endl
+         << "  time = " << ray.time() << embree_endl
+         << "  mask = " << ray.mask << embree_endl
+         << "  id = " << ray.id << embree_endl
+         << "  flags = " << ray.flags << embree_endl
          << "  Ng = " << ray.Ng
-         << "  u = " << ray.u <<  std::endl
-         << "  v = " << ray.v << std::endl
-         << "  primID = " << ray.primID <<  std::endl
-         << "  geomID = " << ray.geomID << std::endl
+         << "  u = " << ray.u <<  embree_endl
+         << "  v = " << ray.v << embree_endl
+         << "  primID = " << ray.primID <<  embree_endl
+         << "  geomID = " << ray.geomID << embree_endl
          << "  instID =";
     for (unsigned l = 0; l < RTC_MAX_INSTANCE_LEVEL_COUNT; ++l)
     {
       cout << " " << ray.instID[l];
     }
-    cout << std::endl;
+    cout << embree_endl;
     return cout << "}";
   }
 
@@ -870,11 +857,13 @@ namespace embree
         *(unsigned int* __restrict__)((char*)geomID + offset) = ray.geomID;
         *(unsigned int* __restrict__)((char*)primID + offset) = ray.primID;
 
-        *(unsigned int* __restrict__)((char*)instID[0] + offset) = ray.instID[0];
+        if (likely(instID[0])) {
+          *(unsigned int* __restrict__)((char*)instID[0] + offset) = ray.instID[0];
 #if (RTC_MAX_INSTANCE_LEVEL_COUNT > 1)
-        for (unsigned l = 1; l < RTC_MAX_INSTANCE_LEVEL_COUNT && ray.instID[l-1] != RTC_INVALID_GEOMETRY_ID; ++l)
-          *(unsigned int* __restrict__)((char*)instID[l] + offset) = ray.instID[l];
+          for (unsigned l = 1; l < RTC_MAX_INSTANCE_LEVEL_COUNT && ray.instID[l-1] != RTC_INVALID_GEOMETRY_ID; ++l)
+            *(unsigned int* __restrict__)((char*)instID[l] + offset) = ray.instID[l];
 #endif
+        }
       }
     }
 
@@ -901,11 +890,13 @@ namespace embree
         vuint<K>::storeu(valid, (unsigned int* __restrict__)((char*)primID + offset), ray.primID);
         vuint<K>::storeu(valid, (unsigned int* __restrict__)((char*)geomID + offset), ray.geomID);
 
-        vuint<K>::storeu(valid, (unsigned int* __restrict__)((char*)instID[0] + offset), ray.instID[0]);
+        if (likely(instID[0])) {
+          vuint<K>::storeu(valid, (unsigned int* __restrict__)((char*)instID[0] + offset), ray.instID[0]);
 #if (RTC_MAX_INSTANCE_LEVEL_COUNT > 1)
-        for (unsigned l = 1; l < RTC_MAX_INSTANCE_LEVEL_COUNT && any(valid & (ray.instID[l-1] != RTC_INVALID_GEOMETRY_ID)); ++l)
-          vuint<K>::storeu(valid, (unsigned int* __restrict__)((char*)instID[l] + offset), ray.instID[l]);
+          for (unsigned l = 1; l < RTC_MAX_INSTANCE_LEVEL_COUNT && any(valid & (ray.instID[l-1] != RTC_INVALID_GEOMETRY_ID)); ++l)
+            vuint<K>::storeu(valid, (unsigned int* __restrict__)((char*)instID[l] + offset), ray.instID[l]);
 #endif
+        }
       }
     }
 
@@ -1015,11 +1006,13 @@ namespace embree
         vuint<K>::template scatter<1>(valid, (unsigned int*)geomID, offset, ray.geomID);
         vuint<K>::template scatter<1>(valid, (unsigned int*)primID, offset, ray.primID);
 
-        vuint<K>::template scatter<1>(valid, (unsigned int*)instID[0], offset, ray.instID[0]);
+        if (likely(instID[0])) {
+          vuint<K>::template scatter<1>(valid, (unsigned int*)instID[0], offset, ray.instID[0]);
 #if (RTC_MAX_INSTANCE_LEVEL_COUNT > 1)
-        for (unsigned l = 1; l < RTC_MAX_INSTANCE_LEVEL_COUNT && any(valid & (ray.instID[l-1] != RTC_INVALID_GEOMETRY_ID)); ++l)
-          vuint<K>::template scatter<1>(valid, (unsigned int*)instID[l], offset, ray.instID[l]);
+          for (unsigned l = 1; l < RTC_MAX_INSTANCE_LEVEL_COUNT && any(valid & (ray.instID[l-1] != RTC_INVALID_GEOMETRY_ID)); ++l)
+            vuint<K>::template scatter<1>(valid, (unsigned int*)instID[l], offset, ray.instID[l]);
 #endif
+        }
 #else
         size_t valid_bits = movemask(valid);
         while (valid_bits != 0)
@@ -1037,11 +1030,13 @@ namespace embree
           *(unsigned int* __restrict__)((char*)primID + ofs) = ray.primID[k];
           *(unsigned int* __restrict__)((char*)geomID + ofs) = ray.geomID[k];
 
-          *(unsigned int* __restrict__)((char*)instID[0] + ofs) = ray.instID[0][k];
+          if (likely(instID[0])) {
+            *(unsigned int* __restrict__)((char*)instID[0] + ofs) = ray.instID[0][k];
 #if (RTC_MAX_INSTANCE_LEVEL_COUNT > 1)
-          for (unsigned l = 1; l < RTC_MAX_INSTANCE_LEVEL_COUNT && ray.instID[l-1][k] != RTC_INVALID_GEOMETRY_ID; ++l)
-            *(unsigned int* __restrict__)((char*)instID[l] + ofs) = ray.instID[l][k];
+            for (unsigned l = 1; l < RTC_MAX_INSTANCE_LEVEL_COUNT && ray.instID[l-1][k] != RTC_INVALID_GEOMETRY_ID; ++l)
+              *(unsigned int* __restrict__)((char*)instID[l] + ofs) = ray.instID[l][k];
 #endif
+          }
         }
 #endif
       }
