@@ -4,7 +4,7 @@
 #pragma once
 
 #include "../../include/embree3/rtcore.h"
-RTC_NAMESPACE_OPEN
+RTC_NAMESPACE_USE
 
 namespace embree
 {  
