@@ -1,18 +1,5 @@
-// ======================================================================== //
-// Copyright 2009-2020 Intel Corporation                                    //
-//                                                                          //
-// Licensed under the Apache License, Version 2.0 (the "License");          //
-// you may not use this file except in compliance with the License.         //
-// You may obtain a copy of the License at                                  //
-//                                                                          //
-//     http://www.apache.org/licenses/LICENSE-2.0                           //
-//                                                                          //
-// Unless required by applicable law or agreed to in writing, software      //
-// distributed under the License is distributed on an "AS IS" BASIS,        //
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. //
-// See the License for the specific language governing permissions and      //
-// limitations under the License.                                           //
-// ======================================================================== //
+// Copyright 2009-2020 Intel Corporation
+// SPDX-License-Identifier: Apache-2.0
 
 #include "scene_line_segments.h"
 #include "scene.h"
@@ -107,6 +94,7 @@ namespace embree
         throw_RTCError(RTC_ERROR_INVALID_OPERATION, "invalid flag buffer format");
 
       flags.set(buffer, offset, stride, num, format);
+      flags.userData = 1; // to encode that app manages this buffer
     }
     else
       throw_RTCError(RTC_ERROR_INVALID_ARGUMENT, "unknown buffer type");
@@ -191,11 +179,14 @@ namespace embree
     Geometry::update();
   }
 
-  void LineSegments::setTessellationRate(float N)
-  {
+  void LineSegments::setTessellationRate(float N) {
     tessellationRate = clamp((int)N,1,16);
   }
 
+  void LineSegments::setMaxRadiusScale(float s) {
+    maxRadiusScale = s;
+  }
+
   void LineSegments::commit() 
   {
     /* verify that stride of all time steps are identical */
@@ -210,7 +201,32 @@ namespace embree
     vertices0 = vertices[0];
     if (getCurveType() == GTY_SUBTYPE_ORIENTED_CURVE)
       normals0 = normals[0];
-        
+
+    /* if no flags buffer is specified we manage and calculate the flags buffer */
+    if (!flags.buffer) flags.userData = 0; // to encode that we manage this buffer
+    bool recompute_flags_buffer = segments.isLocalModified();
+
+    /* resize flags buffer if number of primitives changed */
+    if (!flags.userData && (!flags.buffer || flags.size() != numPrimitives))
+    {
+      Ref<Buffer> buffer = new Buffer(device, numPrimitives*sizeof(char));
+      flags.set(buffer, 0, sizeof(char), numPrimitives, RTC_FORMAT_UCHAR);
+      recompute_flags_buffer = true;
+    }
+
+    /* recalculate the flags buffer if index buffer got modified */
+    if (!flags.userData && recompute_flags_buffer)
+    {
+      bool hasLeft = false;
+      for (size_t i=0; i<numPrimitives; i++) {
+        bool hasRight = (i==numPrimitives-1) ? false : segment(i+1) == segment(i)+1;
+        flags[i]  = hasLeft  * RTC_CURVE_FLAG_NEIGHBOR_LEFT;
+        flags[i] |= hasRight * RTC_CURVE_FLAG_NEIGHBOR_RIGHT;
+        hasLeft = hasRight;
+      }
+    }
+    segments.clearLocalModified();
+
     Geometry::commit();
   }
   
