@@ -1,18 +1,5 @@
-// ======================================================================== //
-// Copyright 2009-2020 Intel Corporation                                    //
-//                                                                          //
-// Licensed under the Apache License, Version 2.0 (the "License");          //
-// you may not use this file except in compliance with the License.         //
-// You may obtain a copy of the License at                                  //
-//                                                                          //
-//     http://www.apache.org/licenses/LICENSE-2.0                           //
-//                                                                          //
-// Unless required by applicable law or agreed to in writing, software      //
-// distributed under the License is distributed on an "AS IS" BASIS,        //
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. //
-// See the License for the specific language governing permissions and      //
-// limitations under the License.                                           //
-// ======================================================================== //
+// Copyright 2009-2020 Intel Corporation
+// SPDX-License-Identifier: Apache-2.0
 
 #pragma once
 
@@ -44,6 +31,7 @@ namespace embree
     bool verify ();
     void interpolate(const RTCInterpolateArguments* const args);
     void setTessellationRate(float N);
+    void setMaxRadiusScale(float s);
     void addElementsToCount (GeometryCounts & counts) const;
 
   public:
@@ -58,16 +46,20 @@ namespace embree
       return segments[i];
     }
 
-    /*! returns the i'th segment */
-    __forceinline unsigned int getStartEndBitMask(size_t i) const {
-      unsigned int mask = 0;
-      if (flags) 
-        mask |= (flags[i] & 0x3) << 30;
-      return mask;
+    /*! returns the segment to the left of the i'th segment */
+    __forceinline bool segmentLeftExists(size_t i) const {
+      assert (flags);
+      return (flags[i] & RTC_CURVE_FLAG_NEIGHBOR_LEFT) != 0;
+    }
+
+    /*! returns the segment to the right of the i'th segment */
+    __forceinline bool segmentRightExists(size_t i) const {
+      assert (flags);
+      return (flags[i] & RTC_CURVE_FLAG_NEIGHBOR_RIGHT) != 0;
     }
 
      /*! returns i'th vertex of the first time step */
-    __forceinline Vec3fa vertex(size_t i) const {
+    __forceinline Vec3ff vertex(size_t i) const {
       return vertices0[i];
     }
 
@@ -87,7 +79,7 @@ namespace embree
     }
 
     /*! returns i'th vertex of itime'th timestep */
-    __forceinline Vec3fa vertex(size_t i, size_t itime) const {
+    __forceinline Vec3ff vertex(size_t i, size_t itime) const {
       return vertices[itime][i];
     }
 
@@ -107,18 +99,18 @@ namespace embree
     }
 
     /*! calculates bounding box of i'th line segment */
-    __forceinline BBox3fa bounds(const Vec3fa& v0, const Vec3fa& v1) const
+    __forceinline BBox3fa bounds(const Vec3ff& v0, const Vec3ff& v1) const
     {
-      const BBox3fa b = merge(BBox3fa(v0),BBox3fa(v1));
-      return enlarge(b,Vec3fa(max(v0.w,v1.w)));
+      const BBox3ff b = merge(BBox3ff(v0),BBox3ff(v1));
+      return enlarge((BBox3fa)b,maxRadiusScale*Vec3fa(max(v0.w,v1.w)));
     }
 
     /*! calculates bounding box of i'th line segment */
     __forceinline BBox3fa bounds(size_t i) const
     {
       const unsigned int index = segment(i);
-      const Vec3fa v0 = vertex(index+0);
-      const Vec3fa v1 = vertex(index+1);
+      const Vec3ff v0 = vertex(index+0);
+      const Vec3ff v1 = vertex(index+1);
       return bounds(v0,v1);
     }
 
@@ -126,8 +118,8 @@ namespace embree
     __forceinline BBox3fa bounds(size_t i, size_t itime) const
     {
       const unsigned int index = segment(i);
-      const Vec3fa v0 = vertex(index+0,itime);
-      const Vec3fa v1 = vertex(index+1,itime);
+      const Vec3ff v0 = vertex(index+0,itime);
+      const Vec3ff v1 = vertex(index+1,itime);
       return bounds(v0,v1);
     }
 
@@ -135,10 +127,10 @@ namespace embree
     __forceinline BBox3fa bounds(const LinearSpace3fa& space, size_t i) const
     {
       const unsigned int index = segment(i);
-      const Vec3fa v0 = vertex(index+0);
-      const Vec3fa v1 = vertex(index+1);
-      const Vec3fa w0(xfmVector(space,v0),v0.w);
-      const Vec3fa w1(xfmVector(space,v1),v1.w);
+      const Vec3ff v0 = vertex(index+0);
+      const Vec3ff v1 = vertex(index+1);
+      const Vec3ff w0(xfmVector(space,(Vec3fa)v0),v0.w);
+      const Vec3ff w1(xfmVector(space,(Vec3fa)v1),v1.w);
       return bounds(w0,w1);
     }
 
@@ -146,10 +138,10 @@ namespace embree
     __forceinline BBox3fa bounds(const LinearSpace3fa& space, size_t i, size_t itime) const
     {
       const unsigned int index = segment(i);
-      const Vec3fa v0 = vertex(index+0,itime);
-      const Vec3fa v1 = vertex(index+1,itime);
-      const Vec3fa w0(xfmVector(space,v0),v0.w);
-      const Vec3fa w1(xfmVector(space,v1),v1.w);
+      const Vec3ff v0 = vertex(index+0,itime);
+      const Vec3ff v1 = vertex(index+1,itime);
+      const Vec3ff w0(xfmVector(space,(Vec3fa)v0),v0.w);
+      const Vec3ff w1(xfmVector(space,(Vec3fa)v1),v1.w);
       return bounds(w0,w1);
     }
 
@@ -166,8 +158,8 @@ namespace embree
       
       for (size_t itime = itime_range.begin(); itime <= itime_range.end(); itime++)
       {
-        const Vec3fa v0 = vertex(index+0,itime); if (unlikely(!isvalid((vfloat4)v0))) return false;
-        const Vec3fa v1 = vertex(index+1,itime); if (unlikely(!isvalid((vfloat4)v1))) return false;
+        const Vec3ff v0 = vertex(index+0,itime); if (unlikely(!isvalid4(v0))) return false;
+        const Vec3ff v1 = vertex(index+1,itime); if (unlikely(!isvalid4(v1))) return false;
         if (min(v0.w,v1.w) < 0.0f) return false;
       }
       return true;
@@ -219,13 +211,14 @@ namespace embree
 
   public:
     BufferView<unsigned int> segments;      //!< array of line segment indices
-    BufferView<Vec3fa> vertices0;           //!< fast access to first vertex buffer
+    BufferView<Vec3ff> vertices0;           //!< fast access to first vertex buffer
     BufferView<Vec3fa> normals0;            //!< fast access to first normal buffer
     BufferView<char> flags;                 //!< start, end flag per segment
-    vector<BufferView<Vec3fa>> vertices;    //!< vertex array for each timestep
+    vector<BufferView<Vec3ff>> vertices;    //!< vertex array for each timestep
     vector<BufferView<Vec3fa>> normals;     //!< normal array for each timestep
     vector<BufferView<char>> vertexAttribs; //!< user buffers
     int tessellationRate;                   //!< tessellation rate for bezier curve
+    float maxRadiusScale = 1.0;             //!< maximal min-width scaling of curve radii
   };
 
   namespace isa
