@@ -164,22 +164,19 @@ namespace embree
     }
 
     /*! calculates the linear bounds of the i'th primitive for the specified time range */
-    __forceinline LBBox3fa linearBounds(size_t primID, const BBox1f& time_range) const
-    {
-      return LBBox3fa([&](size_t itime) { return bounds(primID, itime); }, time_range, fnumTimeSegments);
+    __forceinline LBBox3fa linearBounds(size_t primID, const BBox1f& dt) const {
+      return LBBox3fa([&](size_t itime) { return bounds(primID, itime); }, dt, time_range, fnumTimeSegments);
     }
 
     /*! calculates the linear bounds of the i'th primitive for the specified time range */
-    __forceinline LBBox3fa linearBounds(const LinearSpace3fa& space, size_t primID, const BBox1f& time_range) const
-    {
-      return LBBox3fa([&](size_t itime) { return bounds(space, primID, itime); }, time_range, fnumTimeSegments);
+    __forceinline LBBox3fa linearBounds(const LinearSpace3fa& space, size_t primID, const BBox1f& dt) const {
+      return LBBox3fa([&](size_t itime) { return bounds(space, primID, itime); }, dt, time_range, fnumTimeSegments);
     }
 
     /*! calculates the linear bounds of the i'th primitive for the specified time range */
     __forceinline bool linearBounds(size_t i, const BBox1f& time_range, LBBox3fa& bbox) const
     {
-      if (!valid(i, getTimeSegmentRange(time_range, fnumTimeSegments)))
-        return false;
+      if (!valid(i, timeSegmentRange(time_range))) return false;
       bbox = linearBounds(i, time_range);
       return true;
     }
@@ -250,14 +247,9 @@ namespace embree
       {
         PrimInfoMB pinfo(empty);
         for (size_t j = r.begin(); j < r.end(); j++) {
-          if (!valid(j, getTimeSegmentRange(t0t1, fnumTimeSegments)))
+          if (!valid(j, timeSegmentRange(t0t1)))
             continue;
-          const PrimRefMB prim(linearBounds(j, t0t1),
-                               this->numTimeSegments(),
-                               this->time_range,
-                               this->numTimeSegments(),
-                               geomID,
-                               unsigned(j));
+          const PrimRefMB prim(linearBounds(j, t0t1), this->numTimeSegments(), this->time_range, this->numTimeSegments(), geomID, unsigned(j));
           pinfo.add_primref(prim);
           prims[k++] = prim;
         }
