@@ -146,6 +146,10 @@ namespace embree
     return (enabled_cpu_features & isa) == isa;
   }
 
+  bool State::checkISASupport() {
+    return (getCPUFeatures() & enabled_cpu_features) == enabled_cpu_features;
+  }
+  
   void State::verify()
   {
     /* verify that calculations stay in range */
@@ -178,7 +182,7 @@ namespace embree
 
   const char* symbols[3] = { "=", ",", "|" };
 
-   bool State::parseFile(const FileName& fileName)
+  bool State::parseFile(const FileName& fileName)
   {
     FILE* f = fopen(fileName.c_str(),"r");
     if (!f) return false;
