@@ -1,18 +1,5 @@
-// ======================================================================== //
-// Copyright 2009-2020 Intel Corporation                                    //
-//                                                                          //
-// Licensed under the Apache License, Version 2.0 (the "License");          //
-// you may not use this file except in compliance with the License.         //
-// You may obtain a copy of the License at                                  //
-//                                                                          //
-//     http://www.apache.org/licenses/LICENSE-2.0                           //
-//                                                                          //
-// Unless required by applicable law or agreed to in writing, software      //
-// distributed under the License is distributed on an "AS IS" BASIS,        //
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. //
-// See the License for the specific language governing permissions and      //
-// limitations under the License.                                           //
-// ======================================================================== //
+// Copyright 2009-2020 Intel Corporation
+// SPDX-License-Identifier: Apache-2.0
 
 #pragma once
 
@@ -84,7 +71,7 @@ namespace embree
         /* calculates u and Ng for near hit */
         {
           u0_o = madd(t0,dOz,Oz)*rl;
-          const Vec3fa Pr = t_o.lower*dir;
+          const Vec3fa Pr = t0*dir;
           const Vec3fa Pl = madd(u0_o,p1-p0,p0);
           Ng0_o = Pr-Pl;
         }
@@ -92,7 +79,7 @@ namespace embree
         /* calculates u and Ng for far hit */
         {
           u1_o = madd(t1,dOz,Oz)*rl;
-          const Vec3fa Pr = t_o.lower*dir;
+          const Vec3fa Pr = t1*dir;
           const Vec3fa Pl = madd(u1_o,p1-p0,p0);
           Ng1_o = Pr-Pl;
         }
@@ -119,7 +106,7 @@ namespace embree
         if (shouldhit) failed |= std::isinf(t0) ? t0 != t.lower : abs(t0-t.lower) > eps;
         if (shouldhit) failed |= std::isinf(t1) ? t1 != t.upper : abs(t1-t.upper) > eps;
         if (!failed) return true;
-        std::cout << "Cylinder test " << id << " failed: cylinder = " << cylinder << ", ray = " << ray << ", hit = " << hit << ", t = " << t << std::endl; 
+        embree_cout << "Cylinder test " << id << " failed: cylinder = " << cylinder << ", ray = " << ray << ", hit = " << hit << ", t = " << t << embree_endl; 
         return false;
       }
 
@@ -139,7 +126,7 @@ namespace embree
       }
 
       /*! output operator */
-      friend __forceinline std::ostream& operator<<(std::ostream& cout, const Cylinder& c) {
+      friend __forceinline embree_ostream operator<<(embree_ostream cout, const Cylinder& c) {
         return cout << "Cylinder { p0 = " << c.p0 << ", p1 = " << c.p1 << ", r = " << sqrtf(c.rr) << "}";
       }
     };
