@@ -1,22 +1,10 @@
-// ======================================================================== //
-// Copyright 2009-2020 Intel Corporation                                    //
-//                                                                          //
-// Licensed under the Apache License, Version 2.0 (the "License");          //
-// you may not use this file except in compliance with the License.         //
-// You may obtain a copy of the License at                                  //
-//                                                                          //
-//     http://www.apache.org/licenses/LICENSE-2.0                           //
-//                                                                          //
-// Unless required by applicable law or agreed to in writing, software      //
-// distributed under the License is distributed on an "AS IS" BASIS,        //
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. //
-// See the License for the specific language governing permissions and      //
-// limitations under the License.                                           //
-// ======================================================================== //
+// Copyright 2009-2020 Intel Corporation
+// SPDX-License-Identifier: Apache-2.0
 
 #pragma once
 
 #include "../common/ray.h"
+#include "../common/scene_points.h"
 #include "curve_intersector_precalculations.h"
 
 namespace embree
@@ -62,13 +50,21 @@ namespace embree
 
       template<typename Epilog>
       static __forceinline bool intersect(
-          const vbool<M>& valid_i, Ray& ray, const Precalculations& pre, const Vec4vf<M>& v0, const Epilog& epilog)
+          const vbool<M>& valid_i,
+          Ray& ray,
+          IntersectContext* context,
+          const Points* geom,
+          const Precalculations& pre,
+          const Vec4vf<M>& v0i,
+          const Epilog& epilog)
       {
         vbool<M> valid = valid_i;
 
         const Vec3vf<M> ray_org(ray.org.x, ray.org.y, ray.org.z);
         const Vec3vf<M> ray_dir(ray.dir.x, ray.dir.y, ray.dir.z);
         const vfloat<M> rd2    = rcp(dot(ray_dir, ray_dir));
+
+        const Vec4vf<M> v0 = enlargeRadiusToMinWidth(context,geom,ray_org,v0i);
         const Vec3vf<M> center = v0.xyz();
         const vfloat<M> radius = v0.w;
 
@@ -95,27 +91,32 @@ namespace embree
       template<typename Epilog>
       static __forceinline bool intersect(const vbool<M>& valid_i,
                                           Ray& ray,
+                                          IntersectContext* context,
+                                          const Points* geom,
                                           const Precalculations& pre,
-                                          const Vec4vf<M>& v0,
+                                          const Vec4vf<M>& v0i,
                                           const Vec3vf<M>& normal,
                                           const Epilog& epilog)
       {
         vbool<M> valid         = valid_i;
+        const Vec3vf<M> ray_org(ray.org.x, ray.org.y, ray.org.z);
+
+        const Vec4vf<M> v0 = enlargeRadiusToMinWidth(context,geom,ray_org,v0i);
         const Vec3vf<M> center = v0.xyz();
         const vfloat<M> radius = v0.w;
 
-        vfloat<M> divisor       = dot(Vec3vf<M>(ray.dir), normal);
+        vfloat<M> divisor       = dot(Vec3vf<M>((Vec3fa)ray.dir), normal);
         const vbool<M> parallel = divisor == vfloat<M>(0.f);
         valid &= !parallel;
         divisor = select(parallel, 1.f, divisor);  // prevent divide by zero
 
-        vfloat<M> t = dot(center - Vec3vf<M>(ray.org), Vec3vf<M>(normal)) / divisor;
+        vfloat<M> t = dot(center - Vec3vf<M>((Vec3fa)ray.org), Vec3vf<M>(normal)) / divisor;
 
         valid &= (vfloat<M>(ray.tnear()) <= t) & (t <= vfloat<M>(ray.tfar));
         if (unlikely(none(valid)))
           return false;
 
-        Vec3vf<M> intersection = Vec3vf<M>(ray.org) + Vec3vf<M>(ray.dir) * t;
+        Vec3vf<M> intersection = Vec3vf<M>((Vec3fa)ray.org) + Vec3vf<M>((Vec3fa)ray.dir) * t;
         vfloat<M> dist2        = dot(intersection - center, intersection - center);
         valid &= dist2 < radius * radius;
         if (unlikely(none(valid)))
@@ -135,8 +136,10 @@ namespace embree
       static __forceinline bool intersect(const vbool<M>& valid_i,
                                           RayK<K>& ray,
                                           size_t k,
+                                          IntersectContext* context,
+                                          const Points* geom,
                                           const Precalculations& pre,
-                                          const Vec4vf<M>& v0,
+                                          const Vec4vf<M>& v0i,
                                           const Epilog& epilog)
       {
         vbool<M> valid = valid_i;
@@ -144,6 +147,8 @@ namespace embree
         const Vec3vf<M> ray_org(ray.org.x[k], ray.org.y[k], ray.org.z[k]);
         const Vec3vf<M> ray_dir(ray.dir.x[k], ray.dir.y[k], ray.dir.z[k]);
         const vfloat<M> rd2    = rcp(dot(ray_dir, ray_dir));
+
+        const Vec4vf<M> v0 = enlargeRadiusToMinWidth(context,geom,ray_org,v0i);
         const Vec3vf<M> center = v0.xyz();
         const vfloat<M> radius = v0.w;
 
@@ -171,17 +176,21 @@ namespace embree
       static __forceinline bool intersect(const vbool<M>& valid_i,
                                           RayK<K>& ray,
                                           size_t k,
+                                          IntersectContext* context,
+                                          const Points* geom,
                                           const Precalculations& pre,
-                                          const Vec4vf<M>& v0,
+                                          const Vec4vf<M>& v0i,
                                           const Vec3vf<M>& normal,
                                           const Epilog& epilog)
       {
         vbool<M> valid         = valid_i;
-        const Vec3vf<M> center = v0.xyz();
-        const vfloat<M> radius = v0.w;
         const Vec3vf<M> ray_org(ray.org.x[k], ray.org.y[k], ray.org.z[k]);
         const Vec3vf<M> ray_dir(ray.dir.x[k], ray.dir.y[k], ray.dir.z[k]);
 
+        const Vec4vf<M> v0 = enlargeRadiusToMinWidth(context,geom,ray_org,v0i);
+        const Vec3vf<M> center = v0.xyz();
+        const vfloat<M> radius = v0.w;
+        
         vfloat<M> divisor       = dot(Vec3vf<M>(ray_dir), normal);
         const vbool<M> parallel = divisor == vfloat<M>(0.f);
         valid &= !parallel;
