@@ -1,18 +1,5 @@
-// ======================================================================== //
-// Copyright 2009-2020 Intel Corporation                                    //
-//                                                                          //
-// Licensed under the Apache License, Version 2.0 (the "License");          //
-// you may not use this file except in compliance with the License.         //
-// You may obtain a copy of the License at                                  //
-//                                                                          //
-//     http://www.apache.org/licenses/LICENSE-2.0                           //
-//                                                                          //
-// Unless required by applicable law or agreed to in writing, software      //
-// distributed under the License is distributed on an "AS IS" BASIS,        //
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. //
-// See the License for the specific language governing permissions and      //
-// limitations under the License.                                           //
-// ======================================================================== //
+// Copyright 2009-2020 Intel Corporation
+// SPDX-License-Identifier: Apache-2.0
 
 #pragma once
 
@@ -51,16 +38,24 @@ namespace embree
         
         template<typename Epilog>
         static __forceinline bool intersect(const vbool<M>& valid_i,
-                                            Ray& ray, const Precalculations& pre,
-                                            const Vec4vf<M>& v0, const Vec4vf<M>& v1,
+                                            Ray& ray,
+                                            IntersectContext* context,
+                                            const LineSegments* geom,
+                                            const Precalculations& pre,
+                                            const Vec4vf<M>& v0i, const Vec4vf<M>& v1i,
                                             const Epilog& epilog)
         {
           /* transform end points into ray space */
           vbool<M> valid = valid_i;
           vfloat<M> depth_scale = pre.depth_scale;
           LinearSpace3<Vec3vf<M>> ray_space = pre.ray_space;
-          Vec4vf<M> p0(xfmVector(ray_space,v0.xyz()-Vec3vf<M>(ray.org)), v0.w);
-          Vec4vf<M> p1(xfmVector(ray_space,v1.xyz()-Vec3vf<M>(ray.org)), v1.w);
+
+          const Vec3vf<M> ray_org ((Vec3fa)ray.org);
+          const Vec4vf<M> v0 = enlargeRadiusToMinWidth(context,geom,ray_org,v0i);
+          const Vec4vf<M> v1 = enlargeRadiusToMinWidth(context,geom,ray_org,v1i);
+          
+          Vec4vf<M> p0(xfmVector(ray_space,v0.xyz()-ray_org), v0.w);
+          Vec4vf<M> p1(xfmVector(ray_space,v1.xyz()-ray_org), v1.w);
           
           /* approximative intersection with cone */
           const Vec4vf<M> v = p1-p0;
@@ -96,8 +91,11 @@ namespace embree
         
         template<typename Epilog>
         static __forceinline bool intersect(const vbool<M>& valid_i,
-                                            RayK<K>& ray, size_t k, const Precalculations& pre,
-                                            const Vec4vf<M>& v0, const Vec4vf<M>& v1,
+                                            RayK<K>& ray, size_t k,
+                                            IntersectContext* context,
+                                            const LineSegments* geom,
+                                            const Precalculations& pre,
+                                            const Vec4vf<M>& v0i, const Vec4vf<M>& v1i,
                                             const Epilog& epilog)
         {
           /* transform end points into ray space */
@@ -106,6 +104,10 @@ namespace embree
           LinearSpace3<Vec3vf<M>> ray_space = pre.ray_space[k];
           const Vec3vf<M> ray_org(ray.org.x[k],ray.org.y[k],ray.org.z[k]);
           const Vec3vf<M> ray_dir(ray.dir.x[k],ray.dir.y[k],ray.dir.z[k]);
+
+          const Vec4vf<M> v0 = enlargeRadiusToMinWidth(context,geom,ray_org,v0i);
+          const Vec4vf<M> v1 = enlargeRadiusToMinWidth(context,geom,ray_org,v1i);
+          
           Vec4vf<M> p0(xfmVector(ray_space,v0.xyz()-ray_org), v0.w);
           Vec4vf<M> p1(xfmVector(ray_space,v1.xyz()-ray_org), v1.w);
           
