@@ -40,8 +40,8 @@ namespace embree
     __forceinline LineMi() {  }
 
     /* Construction from vertices and IDs */
-    __forceinline LineMi(const vuint<M>& v0, const vuint<M>& geomIDs, const vuint<M>& primIDs, Geometry::GType gtype)
-      : gtype((unsigned char)gtype), m((unsigned char)popcnt(vuint<M>(primIDs) != vuint<M>(-1))), sharedGeomID(geomIDs[0]), v0(v0), primIDs(primIDs)
+    __forceinline LineMi(const vuint<M>& v0, unsigned short leftExists, unsigned short rightExists, const vuint<M>& geomIDs, const vuint<M>& primIDs, Geometry::GType gtype)
+      : gtype((unsigned char)gtype), m((unsigned char)popcnt(vuint<M>(primIDs) != vuint<M>(-1))), sharedGeomID(geomIDs[0]), leftExists (leftExists), rightExists(rightExists), v0(v0), primIDs(primIDs)
     {
       assert(all(vuint<M>(geomID()) == geomIDs));
     }
@@ -109,6 +109,26 @@ namespace embree
                               const LineSegments* geom,
                               float time) const;
 
+    __forceinline void gather(Vec4vf<M>& p0,
+                              Vec4vf<M>& p1,
+                              vbool<M>& cL,
+                              vbool<M>& cR,
+                              const LineSegments* geom) const;
+
+    __forceinline void gatheri(Vec4vf<M>& p0,
+                               Vec4vf<M>& p1,
+                               vbool<M>& cL,
+                               vbool<M>& cR,
+                               const LineSegments* geom,
+                               const int itime) const;
+
+    __forceinline void gather(Vec4vf<M>& p0,
+                              Vec4vf<M>& p1,
+                              vbool<M>& cL,
+                              vbool<M>& cR,
+                              const LineSegments* geom,
+                              float time) const;
+
     /* Calculate the bounds of the line segments */
     __forceinline const BBox3fa bounds(const Scene* scene, size_t itime = 0) const
     {
@@ -158,6 +178,8 @@ namespace embree
       Geometry::GType gty = scene->get(prims[begin].geomID())->getType();
       vuint<M> geomID, primID;
       vuint<M> v0;
+      unsigned short leftExists = 0;
+      unsigned short rightExists = 0;
       const PrimRefT* prim = &prims[begin];
 
       for (size_t i=0; i<M; i++)
@@ -166,7 +188,9 @@ namespace embree
         if (begin<end) {
           geomID[i] = prim->geomID();
           primID[i] = prim->primID();
-          v0[i] = geom->segment(prim->primID());         
+          v0[i] = geom->segment(prim->primID());
+          leftExists |= geom->segmentLeftExists(primID[i]) << i;
+          rightExists |= geom->segmentRightExists(primID[i]) << i;         
           begin++;
         } else {
           assert(i);
@@ -178,7 +202,7 @@ namespace embree
         }
         if (begin<end) prim = &prims[begin]; // FIXME: remove this line
       }
-      new (this) LineMi(v0,geomID,primID,gty); // FIXME: use non temporal store
+      new (this) LineMi(v0,leftExists,rightExists,geomID,primID,gty); // FIXME: use non temporal store
     }
 
      template<typename BVH, typename Allocator>
@@ -247,6 +271,7 @@ namespace embree
     unsigned char gtype;
     unsigned char m;
     unsigned int sharedGeomID;
+    unsigned short leftExists, rightExists;
     vuint<M> v0;      // index of start vertex
   private:
     vuint<M> primIDs; // primitive ID
@@ -306,6 +331,52 @@ namespace embree
     p1 = lerp(a1,b1,vfloat4(ftime));
   }
 
+  template<>
+    __forceinline void LineMi<4>::gather(Vec4vf4& p0,
+                                         Vec4vf4& p1,
+                                         vbool4&  cL,
+                                         vbool4&  cR,
+                                         const LineSegments* geom) const
+  {
+    gather(p0,p1,geom);
+    cL = !vbool4(leftExists);
+    cR = !vbool4(rightExists);
+  }
+
+  template<>
+    __forceinline void LineMi<4>::gatheri(Vec4vf4& p0,
+                                          Vec4vf4& p1,
+                                          vbool4&  cL,
+                                          vbool4&  cR,
+                                          const LineSegments* geom,
+                                          const int itime) const
+  {
+    gatheri(p0,p1,geom,itime);
+    cL = !vbool4(leftExists);
+    cR = !vbool4(rightExists);
+  }
+
+  template<>
+    __forceinline void LineMi<4>::gather(Vec4vf4& p0,
+                                         Vec4vf4& p1,
+                                         vbool4&  cL,
+                                         vbool4&  cR,
+                                         const LineSegments* geom,
+                                         float time) const
+  {
+    float ftime;
+    const int itime = geom->timeSegment(time, ftime);
+    
+    Vec4vf4 a0,a1;
+    gatheri(a0,a1,geom,itime);
+    Vec4vf4 b0,b1;
+    gatheri(b0,b1,geom,itime+1);
+    p0 = lerp(a0,b0,vfloat4(ftime));
+    p1 = lerp(a1,b1,vfloat4(ftime));
+    cL = !vbool4(leftExists);
+    cR = !vbool4(rightExists);
+  }
+
   template<>
     __forceinline void LineMi<4>::gather(Vec4vf4& p0,
                                               Vec4vf4& p1,
@@ -325,16 +396,16 @@ namespace embree
     const vfloat4 b3 = vfloat4::loadu(geom->vertexPtr(v0[3]+1));
     transpose(b0,b1,b2,b3,p1.x,p1.y,p1.z,p1.w);
     
-    const vfloat4 l0 = (primIDs[0] != -1 && geom->segmentLeftExists(primIDs[0])) ? vfloat4::loadu(geom->vertexPtr(v0[0]-1)) : vfloat4(inf);
-    const vfloat4 l1 = (primIDs[1] != -1 && geom->segmentLeftExists(primIDs[1])) ? vfloat4::loadu(geom->vertexPtr(v0[1]-1)) : vfloat4(inf);
-    const vfloat4 l2 = (primIDs[2] != -1 && geom->segmentLeftExists(primIDs[2])) ? vfloat4::loadu(geom->vertexPtr(v0[2]-1)) : vfloat4(inf);
-    const vfloat4 l3 = (primIDs[3] != -1 && geom->segmentLeftExists(primIDs[3])) ? vfloat4::loadu(geom->vertexPtr(v0[3]-1)) : vfloat4(inf);
+    const vfloat4 l0 = (leftExists & (1<<0)) ? vfloat4::loadu(geom->vertexPtr(v0[0]-1)) : vfloat4(inf);
+    const vfloat4 l1 = (leftExists & (1<<1)) ? vfloat4::loadu(geom->vertexPtr(v0[1]-1)) : vfloat4(inf);
+    const vfloat4 l2 = (leftExists & (1<<2)) ? vfloat4::loadu(geom->vertexPtr(v0[2]-1)) : vfloat4(inf);
+    const vfloat4 l3 = (leftExists & (1<<3)) ? vfloat4::loadu(geom->vertexPtr(v0[3]-1)) : vfloat4(inf);
     transpose(l0,l1,l2,l3,pL.x,pL.y,pL.z,pL.w);
     
-    const vfloat4 r0 = (primIDs[0] != -1 && geom->segmentRightExists(primIDs[0])) ? vfloat4::loadu(geom->vertexPtr(v0[0]+2)) : vfloat4(inf);
-    const vfloat4 r1 = (primIDs[1] != -1 && geom->segmentRightExists(primIDs[1])) ? vfloat4::loadu(geom->vertexPtr(v0[1]+2)) : vfloat4(inf);
-    const vfloat4 r2 = (primIDs[2] != -1 && geom->segmentRightExists(primIDs[2])) ? vfloat4::loadu(geom->vertexPtr(v0[2]+2)) : vfloat4(inf);
-    const vfloat4 r3 = (primIDs[3] != -1 && geom->segmentRightExists(primIDs[3])) ? vfloat4::loadu(geom->vertexPtr(v0[3]+2)) : vfloat4(inf);
+    const vfloat4 r0 = (rightExists & (1<<0)) ? vfloat4::loadu(geom->vertexPtr(v0[0]+2)) : vfloat4(inf);
+    const vfloat4 r1 = (rightExists & (1<<1)) ? vfloat4::loadu(geom->vertexPtr(v0[1]+2)) : vfloat4(inf);
+    const vfloat4 r2 = (rightExists & (1<<2)) ? vfloat4::loadu(geom->vertexPtr(v0[2]+2)) : vfloat4(inf);
+    const vfloat4 r3 = (rightExists & (1<<3)) ? vfloat4::loadu(geom->vertexPtr(v0[3]+2)) : vfloat4(inf);
     transpose(r0,r1,r2,r3,pR.x,pR.y,pR.z,pR.w);
   }
   
@@ -358,16 +429,16 @@ namespace embree
     const vfloat4 b3 = vfloat4::loadu(geom->vertexPtr(v0[3]+1,itime));
     transpose(b0,b1,b2,b3,p1.x,p1.y,p1.z,p1.w);
     
-    const vfloat4 l0 = (primIDs[0] != -1 && geom->segmentLeftExists(primIDs[0])) ? vfloat4::loadu(geom->vertexPtr(v0[0]-1,itime)) : vfloat4(inf);
-    const vfloat4 l1 = (primIDs[1] != -1 && geom->segmentLeftExists(primIDs[1])) ? vfloat4::loadu(geom->vertexPtr(v0[1]-1,itime)) : vfloat4(inf);
-    const vfloat4 l2 = (primIDs[2] != -1 && geom->segmentLeftExists(primIDs[2])) ? vfloat4::loadu(geom->vertexPtr(v0[2]-1,itime)) : vfloat4(inf);
-    const vfloat4 l3 = (primIDs[3] != -1 && geom->segmentLeftExists(primIDs[3])) ? vfloat4::loadu(geom->vertexPtr(v0[3]-1,itime)) : vfloat4(inf);
+    const vfloat4 l0 = (leftExists & (1<<0)) ? vfloat4::loadu(geom->vertexPtr(v0[0]-1,itime)) : vfloat4(inf);
+    const vfloat4 l1 = (leftExists & (1<<1)) ? vfloat4::loadu(geom->vertexPtr(v0[1]-1,itime)) : vfloat4(inf);
+    const vfloat4 l2 = (leftExists & (1<<2)) ? vfloat4::loadu(geom->vertexPtr(v0[2]-1,itime)) : vfloat4(inf);
+    const vfloat4 l3 = (leftExists & (1<<3)) ? vfloat4::loadu(geom->vertexPtr(v0[3]-1,itime)) : vfloat4(inf);
     transpose(l0,l1,l2,l3,pL.x,pL.y,pL.z,pL.w);
     
-    const vfloat4 r0 = (primIDs[0] != -1 && geom->segmentRightExists(primIDs[0])) ? vfloat4::loadu(geom->vertexPtr(v0[0]+2,itime)) : vfloat4(inf);
-    const vfloat4 r1 = (primIDs[1] != -1 && geom->segmentRightExists(primIDs[1])) ? vfloat4::loadu(geom->vertexPtr(v0[1]+2,itime)) : vfloat4(inf);
-    const vfloat4 r2 = (primIDs[2] != -1 && geom->segmentRightExists(primIDs[2])) ? vfloat4::loadu(geom->vertexPtr(v0[2]+2,itime)) : vfloat4(inf);
-    const vfloat4 r3 = (primIDs[3] != -1 && geom->segmentRightExists(primIDs[3])) ? vfloat4::loadu(geom->vertexPtr(v0[3]+2,itime)) : vfloat4(inf);
+    const vfloat4 r0 = (rightExists & (1<<0)) ? vfloat4::loadu(geom->vertexPtr(v0[0]+2,itime)) : vfloat4(inf);
+    const vfloat4 r1 = (rightExists & (1<<1)) ? vfloat4::loadu(geom->vertexPtr(v0[1]+2,itime)) : vfloat4(inf);
+    const vfloat4 r2 = (rightExists & (1<<2)) ? vfloat4::loadu(geom->vertexPtr(v0[2]+2,itime)) : vfloat4(inf);
+    const vfloat4 r3 = (rightExists & (1<<3)) ? vfloat4::loadu(geom->vertexPtr(v0[3]+2,itime)) : vfloat4(inf);
     transpose(r0,r1,r2,r3,pR.x,pR.y,pR.z,pR.w);
   }
   
@@ -491,24 +562,24 @@ namespace embree
     const vfloat4 b7 = vfloat4::loadu(geom->vertexPtr(v0[7]+1));
     transpose(b0,b1,b2,b3,b4,b5,b6,b7,p1.x,p1.y,p1.z,p1.w);
     
-    const vfloat4 l0 = (primIDs[0] != -1 && geom->segmentLeftExists(primIDs[0])) ? vfloat4::loadu(geom->vertexPtr(v0[0]-1)) : vfloat4(inf);
-    const vfloat4 l1 = (primIDs[1] != -1 && geom->segmentLeftExists(primIDs[1])) ? vfloat4::loadu(geom->vertexPtr(v0[1]-1)) : vfloat4(inf);
-    const vfloat4 l2 = (primIDs[2] != -1 && geom->segmentLeftExists(primIDs[2])) ? vfloat4::loadu(geom->vertexPtr(v0[2]-1)) : vfloat4(inf);
-    const vfloat4 l3 = (primIDs[3] != -1 && geom->segmentLeftExists(primIDs[3])) ? vfloat4::loadu(geom->vertexPtr(v0[3]-1)) : vfloat4(inf);
-    const vfloat4 l4 = (primIDs[4] != -1 && geom->segmentLeftExists(primIDs[4])) ? vfloat4::loadu(geom->vertexPtr(v0[4]-1)) : vfloat4(inf);
-    const vfloat4 l5 = (primIDs[5] != -1 && geom->segmentLeftExists(primIDs[5])) ? vfloat4::loadu(geom->vertexPtr(v0[5]-1)) : vfloat4(inf);
-    const vfloat4 l6 = (primIDs[6] != -1 && geom->segmentLeftExists(primIDs[6])) ? vfloat4::loadu(geom->vertexPtr(v0[6]-1)) : vfloat4(inf);
-    const vfloat4 l7 = (primIDs[7] != -1 && geom->segmentLeftExists(primIDs[7])) ? vfloat4::loadu(geom->vertexPtr(v0[7]-1)) : vfloat4(inf);
+    const vfloat4 l0 = (leftExists & (1<<0)) ? vfloat4::loadu(geom->vertexPtr(v0[0]-1)) : vfloat4(inf);
+    const vfloat4 l1 = (leftExists & (1<<1)) ? vfloat4::loadu(geom->vertexPtr(v0[1]-1)) : vfloat4(inf);
+    const vfloat4 l2 = (leftExists & (1<<2)) ? vfloat4::loadu(geom->vertexPtr(v0[2]-1)) : vfloat4(inf);
+    const vfloat4 l3 = (leftExists & (1<<3)) ? vfloat4::loadu(geom->vertexPtr(v0[3]-1)) : vfloat4(inf);
+    const vfloat4 l4 = (leftExists & (1<<4)) ? vfloat4::loadu(geom->vertexPtr(v0[4]-1)) : vfloat4(inf);
+    const vfloat4 l5 = (leftExists & (1<<5)) ? vfloat4::loadu(geom->vertexPtr(v0[5]-1)) : vfloat4(inf);
+    const vfloat4 l6 = (leftExists & (1<<6)) ? vfloat4::loadu(geom->vertexPtr(v0[6]-1)) : vfloat4(inf);
+    const vfloat4 l7 = (leftExists & (1<<7)) ? vfloat4::loadu(geom->vertexPtr(v0[7]-1)) : vfloat4(inf);
     transpose(l0,l1,l2,l3,l4,l5,l6,l7,pL.x,pL.y,pL.z,pL.w);
     
-    const vfloat4 r0 = (primIDs[0] != -1 && geom->segmentRightExists(primIDs[0])) ? vfloat4::loadu(geom->vertexPtr(v0[0]+2)) : vfloat4(inf);
-    const vfloat4 r1 = (primIDs[1] != -1 && geom->segmentRightExists(primIDs[1])) ? vfloat4::loadu(geom->vertexPtr(v0[1]+2)) : vfloat4(inf);
-    const vfloat4 r2 = (primIDs[2] != -1 && geom->segmentRightExists(primIDs[2])) ? vfloat4::loadu(geom->vertexPtr(v0[2]+2)) : vfloat4(inf);
-    const vfloat4 r3 = (primIDs[3] != -1 && geom->segmentRightExists(primIDs[3])) ? vfloat4::loadu(geom->vertexPtr(v0[3]+2)) : vfloat4(inf);
-    const vfloat4 r4 = (primIDs[4] != -1 && geom->segmentRightExists(primIDs[4])) ? vfloat4::loadu(geom->vertexPtr(v0[4]+2)) : vfloat4(inf);
-    const vfloat4 r5 = (primIDs[5] != -1 && geom->segmentRightExists(primIDs[5])) ? vfloat4::loadu(geom->vertexPtr(v0[5]+2)) : vfloat4(inf);
-    const vfloat4 r6 = (primIDs[6] != -1 && geom->segmentRightExists(primIDs[6])) ? vfloat4::loadu(geom->vertexPtr(v0[6]+2)) : vfloat4(inf);
-    const vfloat4 r7 = (primIDs[7] != -1 && geom->segmentRightExists(primIDs[7])) ? vfloat4::loadu(geom->vertexPtr(v0[7]+2)) : vfloat4(inf);
+    const vfloat4 r0 = (rightExists & (1<<0)) ? vfloat4::loadu(geom->vertexPtr(v0[0]+2)) : vfloat4(inf);
+    const vfloat4 r1 = (rightExists & (1<<1)) ? vfloat4::loadu(geom->vertexPtr(v0[1]+2)) : vfloat4(inf);
+    const vfloat4 r2 = (rightExists & (1<<2)) ? vfloat4::loadu(geom->vertexPtr(v0[2]+2)) : vfloat4(inf);
+    const vfloat4 r3 = (rightExists & (1<<3)) ? vfloat4::loadu(geom->vertexPtr(v0[3]+2)) : vfloat4(inf);
+    const vfloat4 r4 = (rightExists & (1<<4)) ? vfloat4::loadu(geom->vertexPtr(v0[4]+2)) : vfloat4(inf);
+    const vfloat4 r5 = (rightExists & (1<<5)) ? vfloat4::loadu(geom->vertexPtr(v0[5]+2)) : vfloat4(inf);
+    const vfloat4 r6 = (rightExists & (1<<6)) ? vfloat4::loadu(geom->vertexPtr(v0[6]+2)) : vfloat4(inf);
+    const vfloat4 r7 = (rightExists & (1<<7)) ? vfloat4::loadu(geom->vertexPtr(v0[7]+2)) : vfloat4(inf);
     transpose(r0,r1,r2,r3,r4,r5,r6,r7,pR.x,pR.y,pR.z,pR.w);
   }
   
@@ -540,24 +611,24 @@ namespace embree
     const vfloat4 b7 = vfloat4::loadu(geom->vertexPtr(v0[7]+1,itime));
     transpose(b0,b1,b2,b3,b4,b5,b6,b7,p1.x,p1.y,p1.z,p1.w);
     
-    const vfloat4 l0 = (primIDs[0] != -1 && geom->segmentLeftExists(primIDs[0])) ? vfloat4::loadu(geom->vertexPtr(v0[0]-1,itime)) : vfloat4(inf);
-    const vfloat4 l1 = (primIDs[1] != -1 && geom->segmentLeftExists(primIDs[1])) ? vfloat4::loadu(geom->vertexPtr(v0[1]-1,itime)) : vfloat4(inf);
-    const vfloat4 l2 = (primIDs[2] != -1 && geom->segmentLeftExists(primIDs[2])) ? vfloat4::loadu(geom->vertexPtr(v0[2]-1,itime)) : vfloat4(inf);
-    const vfloat4 l3 = (primIDs[3] != -1 && geom->segmentLeftExists(primIDs[3])) ? vfloat4::loadu(geom->vertexPtr(v0[3]-1,itime)) : vfloat4(inf);
-    const vfloat4 l4 = (primIDs[4] != -1 && geom->segmentLeftExists(primIDs[4])) ? vfloat4::loadu(geom->vertexPtr(v0[4]-1,itime)) : vfloat4(inf);
-    const vfloat4 l5 = (primIDs[5] != -1 && geom->segmentLeftExists(primIDs[5])) ? vfloat4::loadu(geom->vertexPtr(v0[5]-1,itime)) : vfloat4(inf);
-    const vfloat4 l6 = (primIDs[6] != -1 && geom->segmentLeftExists(primIDs[6])) ? vfloat4::loadu(geom->vertexPtr(v0[6]-1,itime)) : vfloat4(inf);
-    const vfloat4 l7 = (primIDs[7] != -1 && geom->segmentLeftExists(primIDs[7])) ? vfloat4::loadu(geom->vertexPtr(v0[7]-1,itime)) : vfloat4(inf);
+    const vfloat4 l0 = (leftExists & (1<<0)) ? vfloat4::loadu(geom->vertexPtr(v0[0]-1,itime)) : vfloat4(inf);
+    const vfloat4 l1 = (leftExists & (1<<1)) ? vfloat4::loadu(geom->vertexPtr(v0[1]-1,itime)) : vfloat4(inf);
+    const vfloat4 l2 = (leftExists & (1<<2)) ? vfloat4::loadu(geom->vertexPtr(v0[2]-1,itime)) : vfloat4(inf);
+    const vfloat4 l3 = (leftExists & (1<<3)) ? vfloat4::loadu(geom->vertexPtr(v0[3]-1,itime)) : vfloat4(inf);
+    const vfloat4 l4 = (leftExists & (1<<4)) ? vfloat4::loadu(geom->vertexPtr(v0[4]-1,itime)) : vfloat4(inf);
+    const vfloat4 l5 = (leftExists & (1<<5)) ? vfloat4::loadu(geom->vertexPtr(v0[5]-1,itime)) : vfloat4(inf);
+    const vfloat4 l6 = (leftExists & (1<<6)) ? vfloat4::loadu(geom->vertexPtr(v0[6]-1,itime)) : vfloat4(inf);
+    const vfloat4 l7 = (leftExists & (1<<7)) ? vfloat4::loadu(geom->vertexPtr(v0[7]-1,itime)) : vfloat4(inf);
     transpose(l0,l1,l2,l3,l4,l5,l6,l7,pL.x,pL.y,pL.z,pL.w);
     
-    const vfloat4 r0 = (primIDs[0] != -1 && geom->segmentRightExists(primIDs[0])) ? vfloat4::loadu(geom->vertexPtr(v0[0]+2,itime)) : vfloat4(inf);
-    const vfloat4 r1 = (primIDs[1] != -1 && geom->segmentRightExists(primIDs[1])) ? vfloat4::loadu(geom->vertexPtr(v0[1]+2,itime)) : vfloat4(inf);
-    const vfloat4 r2 = (primIDs[2] != -1 && geom->segmentRightExists(primIDs[2])) ? vfloat4::loadu(geom->vertexPtr(v0[2]+2,itime)) : vfloat4(inf);
-    const vfloat4 r3 = (primIDs[3] != -1 && geom->segmentRightExists(primIDs[3])) ? vfloat4::loadu(geom->vertexPtr(v0[3]+2,itime)) : vfloat4(inf);
-    const vfloat4 r4 = (primIDs[4] != -1 && geom->segmentRightExists(primIDs[4])) ? vfloat4::loadu(geom->vertexPtr(v0[4]+2,itime)) : vfloat4(inf);
-    const vfloat4 r5 = (primIDs[5] != -1 && geom->segmentRightExists(primIDs[5])) ? vfloat4::loadu(geom->vertexPtr(v0[5]+2,itime)) : vfloat4(inf);
-    const vfloat4 r6 = (primIDs[6] != -1 && geom->segmentRightExists(primIDs[6])) ? vfloat4::loadu(geom->vertexPtr(v0[6]+2,itime)) : vfloat4(inf);
-    const vfloat4 r7 = (primIDs[7] != -1 && geom->segmentRightExists(primIDs[7])) ? vfloat4::loadu(geom->vertexPtr(v0[7]+2,itime)) : vfloat4(inf);
+    const vfloat4 r0 = (rightExists & (1<<0)) ? vfloat4::loadu(geom->vertexPtr(v0[0]+2,itime)) : vfloat4(inf);
+    const vfloat4 r1 = (rightExists & (1<<1)) ? vfloat4::loadu(geom->vertexPtr(v0[1]+2,itime)) : vfloat4(inf);
+    const vfloat4 r2 = (rightExists & (1<<2)) ? vfloat4::loadu(geom->vertexPtr(v0[2]+2,itime)) : vfloat4(inf);
+    const vfloat4 r3 = (rightExists & (1<<3)) ? vfloat4::loadu(geom->vertexPtr(v0[3]+2,itime)) : vfloat4(inf);
+    const vfloat4 r4 = (rightExists & (1<<4)) ? vfloat4::loadu(geom->vertexPtr(v0[4]+2,itime)) : vfloat4(inf);
+    const vfloat4 r5 = (rightExists & (1<<5)) ? vfloat4::loadu(geom->vertexPtr(v0[5]+2,itime)) : vfloat4(inf);
+    const vfloat4 r6 = (rightExists & (1<<6)) ? vfloat4::loadu(geom->vertexPtr(v0[6]+2,itime)) : vfloat4(inf);
+    const vfloat4 r7 = (rightExists & (1<<7)) ? vfloat4::loadu(geom->vertexPtr(v0[7]+2,itime)) : vfloat4(inf);
     transpose(r0,r1,r2,r3,r4,r5,r6,r7,pR.x,pR.y,pR.z,pR.w);
   }
   
@@ -581,6 +652,52 @@ namespace embree
     pL = lerp(aL,bL,vfloat8(ftime));
     pR = lerp(aR,bR,vfloat8(ftime));
   }
+
+  template<>
+    __forceinline void LineMi<8>::gather(Vec4vf8& p0,
+                                         Vec4vf8& p1,
+                                         vbool8& cL,
+                                         vbool8& cR,
+                                         const LineSegments* geom) const
+  {
+    gather(p0,p1,geom);
+    cL = !vbool8(leftExists);
+    cR = !vbool8(rightExists);
+  }
+  
+  template<>
+    __forceinline void LineMi<8>::gatheri(Vec4vf8& p0,
+                                              Vec4vf8& p1,
+                                              vbool8& cL,
+                                              vbool8& cR,
+                                              const LineSegments* geom,
+                                              const int itime) const
+  {
+    gatheri(p0,p1,geom,itime);
+    cL = !vbool8(leftExists);
+    cR = !vbool8(rightExists);
+  }
+  
+  template<>
+    __forceinline void LineMi<8>::gather(Vec4vf8& p0,
+                                              Vec4vf8& p1,
+                                              vbool8& cL,
+                                              vbool8& cR,
+                                              const LineSegments* geom,
+                                              float time) const
+  {
+    float ftime;
+    const int itime = geom->timeSegment(time, ftime);
+    
+    Vec4vf8 a0,a1;
+    gatheri(a0,a1,geom,itime);
+    Vec4vf8 b0,b1;
+    gatheri(b0,b1,geom,itime+1);
+    p0 = lerp(a0,b0,vfloat8(ftime));
+    p1 = lerp(a1,b1,vfloat8(ftime));
+    cL = !vbool8(leftExists);
+    cR = !vbool8(rightExists);
+  }
   
 #endif
   
