@@ -1,18 +1,5 @@
-// ======================================================================== //
-// Copyright 2009-2020 Intel Corporation                                    //
-//                                                                          //
-// Licensed under the Apache License, Version 2.0 (the "License");          //
-// you may not use this file except in compliance with the License.         //
-// You may obtain a copy of the License at                                  //
-//                                                                          //
-//     http://www.apache.org/licenses/LICENSE-2.0                           //
-//                                                                          //
-// Unless required by applicable law or agreed to in writing, software      //
-// distributed under the License is distributed on an "AS IS" BASIS,        //
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. //
-// See the License for the specific language governing permissions and      //
-// limitations under the License.                                           //
-// ======================================================================== //
+// Copyright 2009-2020 Intel Corporation
+// SPDX-License-Identifier: Apache-2.0
 
 #pragma once
 
@@ -36,11 +23,11 @@ namespace embree
                                           const Primitive& sphere)
       {
         STAT3(normal.trav_prims, 1, 1, 1);
-        Vec4vf<M> v0;
-        sphere.gather(v0, context->scene);
+        const Points* geom = context->scene->get<Points>(sphere.geomID());
+        Vec4vf<M> v0; sphere.gather(v0, geom);
         const vbool<Mx> valid = sphere.template valid<Mx>();
         SphereIntersector1<Mx>::intersect(
-            valid, ray, pre, v0, Intersect1EpilogM<M, Mx, filter>(ray, context, sphere.geomID(), sphere.primID()));
+          valid, ray, context, geom, pre, v0, Intersect1EpilogM<M, Mx, filter>(ray, context, sphere.geomID(), sphere.primID()));
       }
 
       static __forceinline bool occluded(const Precalculations& pre,
@@ -49,11 +36,11 @@ namespace embree
                                          const Primitive& sphere)
       {
         STAT3(shadow.trav_prims, 1, 1, 1);
-        Vec4vf<M> v0;
-        sphere.gather(v0, context->scene);
+        const Points* geom = context->scene->get<Points>(sphere.geomID());
+        Vec4vf<M> v0; sphere.gather(v0, geom);
         const vbool<Mx> valid = sphere.template valid<Mx>();
         return SphereIntersector1<Mx>::intersect(
-            valid, ray, pre, v0, Occluded1EpilogM<M, Mx, filter>(ray, context, sphere.geomID(), sphere.primID()));
+          valid, ray, context, geom, pre, v0, Occluded1EpilogM<M, Mx, filter>(ray, context, sphere.geomID(), sphere.primID()));
       }
       
       static __forceinline bool pointQuery(PointQuery* query,
@@ -76,11 +63,11 @@ namespace embree
                                           const Primitive& sphere)
       {
         STAT3(normal.trav_prims, 1, 1, 1);
-        Vec4vf<M> v0;
-        sphere.gather(v0, context->scene, ray.time());
+        const Points* geom = context->scene->get<Points>(sphere.geomID());
+        Vec4vf<M> v0; sphere.gather(v0, geom, ray.time());
         const vbool<Mx> valid = sphere.template valid<Mx>();
         SphereIntersector1<Mx>::intersect(
-            valid, ray, pre, v0, Intersect1EpilogM<M, Mx, filter>(ray, context, sphere.geomID(), sphere.primID()));
+          valid, ray, context, geom, pre, v0, Intersect1EpilogM<M, Mx, filter>(ray, context, sphere.geomID(), sphere.primID()));
       }
 
       static __forceinline bool occluded(const Precalculations& pre,
@@ -89,11 +76,11 @@ namespace embree
                                          const Primitive& sphere)
       {
         STAT3(shadow.trav_prims, 1, 1, 1);
-        Vec4vf<M> v0;
-        sphere.gather(v0, context->scene, ray.time());
+        const Points* geom = context->scene->get<Points>(sphere.geomID());
+        Vec4vf<M> v0; sphere.gather(v0, geom, ray.time());
         const vbool<Mx> valid = sphere.template valid<Mx>();
         return SphereIntersector1<Mx>::intersect(
-            valid, ray, pre, v0, Occluded1EpilogM<M, Mx, filter>(ray, context, sphere.geomID(), sphere.primID()));
+          valid, ray, context, geom, pre, v0, Occluded1EpilogM<M, Mx, filter>(ray, context, sphere.geomID(), sphere.primID()));
       }
 
       static __forceinline bool pointQuery(PointQuery* query,
@@ -114,32 +101,24 @@ namespace embree
           const Precalculations& pre, RayHitK<K>& ray, size_t k, IntersectContext* context, const Primitive& sphere)
       {
         STAT3(normal.trav_prims, 1, 1, 1);
-        Vec4vf<M> v0;
-        sphere.gather(v0, context->scene);
+        const Points* geom = context->scene->get<Points>(sphere.geomID());
+        Vec4vf<M> v0; sphere.gather(v0, geom);
         const vbool<Mx> valid = sphere.template valid<Mx>();
         SphereIntersectorK<Mx, K>::intersect(
-            valid,
-            ray,
-            k,
-            pre,
-            v0,
-            Intersect1KEpilogM<M, Mx, K, filter>(ray, k, context, sphere.geomID(), sphere.primID()));
+          valid, ray, k, context, geom, pre, v0,
+          Intersect1KEpilogM<M, Mx, K, filter>(ray, k, context, sphere.geomID(), sphere.primID()));
       }
 
       static __forceinline bool occluded(
           const Precalculations& pre, RayK<K>& ray, size_t k, IntersectContext* context, const Primitive& sphere)
       {
         STAT3(shadow.trav_prims, 1, 1, 1);
-        Vec4vf<M> v0;
-        sphere.gather(v0, context->scene);
+        const Points* geom = context->scene->get<Points>(sphere.geomID());
+        Vec4vf<M> v0; sphere.gather(v0, geom);
         const vbool<Mx> valid = sphere.template valid<Mx>();
         return SphereIntersectorK<Mx, K>::intersect(
-            valid,
-            ray,
-            k,
-            pre,
-            v0,
-            Occluded1KEpilogM<M, Mx, K, filter>(ray, k, context, sphere.geomID(), sphere.primID()));
+          valid, ray, k, context, geom, pre, v0,
+          Occluded1KEpilogM<M, Mx, K, filter>(ray, k, context, sphere.geomID(), sphere.primID()));
       }
     };
 
@@ -153,32 +132,24 @@ namespace embree
           const Precalculations& pre, RayHitK<K>& ray, size_t k, IntersectContext* context, const Primitive& sphere)
       {
         STAT3(normal.trav_prims, 1, 1, 1);
-        Vec4vf<M> v0;
-        sphere.gather(v0, context->scene, ray.time()[k]);
+        const Points* geom = context->scene->get<Points>(sphere.geomID());
+        Vec4vf<M> v0; sphere.gather(v0, geom, ray.time()[k]);
         const vbool<Mx> valid = sphere.template valid<Mx>();
         SphereIntersectorK<Mx, K>::intersect(
-            valid,
-            ray,
-            k,
-            pre,
-            v0,
-            Intersect1KEpilogM<M, Mx, K, filter>(ray, k, context, sphere.geomID(), sphere.primID()));
+          valid, ray, k, context, geom, pre, v0,
+          Intersect1KEpilogM<M, Mx, K, filter>(ray, k, context, sphere.geomID(), sphere.primID()));
       }
 
       static __forceinline bool occluded(
           const Precalculations& pre, RayK<K>& ray, size_t k, IntersectContext* context, const Primitive& sphere)
       {
         STAT3(shadow.trav_prims, 1, 1, 1);
-        Vec4vf<M> v0;
-        sphere.gather(v0, context->scene, ray.time()[k]);
+        const Points* geom = context->scene->get<Points>(sphere.geomID());
+        Vec4vf<M> v0; sphere.gather(v0, geom, ray.time()[k]);
         const vbool<Mx> valid = sphere.template valid<Mx>();
         return SphereIntersectorK<Mx, K>::intersect(
-            valid,
-            ray,
-            k,
-            pre,
-            v0,
-            Occluded1KEpilogM<M, Mx, K, filter>(ray, k, context, sphere.geomID(), sphere.primID()));
+          valid, ray, k, context, geom, pre, v0,
+          Occluded1KEpilogM<M, Mx, K, filter>(ray, k, context, sphere.geomID(), sphere.primID()));
       }
     };
   }  // namespace isa
