@@ -1,18 +1,5 @@
-// ======================================================================== //
-// Copyright 2009-2020 Intel Corporation                                    //
-//                                                                          //
-// Licensed under the Apache License, Version 2.0 (the "License");          //
-// you may not use this file except in compliance with the License.         //
-// You may obtain a copy of the License at                                  //
-//                                                                          //
-//     http://www.apache.org/licenses/LICENSE-2.0                           //
-//                                                                          //
-// Unless required by applicable law or agreed to in writing, software      //
-// distributed under the License is distributed on an "AS IS" BASIS,        //
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. //
-// See the License for the specific language governing permissions and      //
-// limitations under the License.                                           //
-// ======================================================================== //
+// Copyright 2009-2020 Intel Corporation
+// SPDX-License-Identifier: Apache-2.0
 
 #pragma once
 
@@ -65,9 +52,9 @@ namespace embree
         {
           if (!tri.valid(i)) break;
           STAT3(normal.trav_prims,1,popcnt(valid_i),RayHitK<K>::size());
-          const Vec3vf<K> v0 = tri.getVertex(tri.v0,i,scene);
-          const Vec3vf<K> v1 = tri.getVertex(tri.v1,i,scene);
-          const Vec3vf<K> v2 = tri.getVertex(tri.v2,i,scene);
+          const Vec3vf<K> v0 = tri.template getVertex<0>(i,scene);
+          const Vec3vf<K> v1 = tri.template getVertex<1>(i,scene);
+          const Vec3vf<K> v2 = tri.template getVertex<2>(i,scene);
           pre.intersectK(valid_i,ray,v0,v1,v2,/*UVIdentity<K>(),*/IntersectKEpilogM<M,K,filter>(ray,context,tri.geomID(),tri.primID(),i));
         }
       }
@@ -81,9 +68,9 @@ namespace embree
         {
           if (!tri.valid(i)) break;
           STAT3(shadow.trav_prims,1,popcnt(valid_i),RayHitK<K>::size());
-          const Vec3vf<K> v0 = tri.getVertex(tri.v0,i,scene);
-          const Vec3vf<K> v1 = tri.getVertex(tri.v1,i,scene);
-          const Vec3vf<K> v2 = tri.getVertex(tri.v2,i,scene);
+          const Vec3vf<K> v0 = tri.template getVertex<0>(i,scene);
+          const Vec3vf<K> v1 = tri.template getVertex<1>(i,scene);
+          const Vec3vf<K> v2 = tri.template getVertex<2>(i,scene);
           pre.intersectK(valid0,ray,v0,v1,v2,/*UVIdentity<K>(),*/OccludedKEpilogM<M,K,filter>(valid0,ray,context,tri.geomID(),tri.primID(),i));
           if (none(valid0)) break;
         }
@@ -146,9 +133,9 @@ namespace embree
         {
           if (!tri.valid(i)) break;
           STAT3(normal.trav_prims,1,popcnt(valid_i),RayHitK<K>::size());
-          const Vec3vf<K> v0 = tri.getVertex(tri.v0,i,scene);
-          const Vec3vf<K> v1 = tri.getVertex(tri.v1,i,scene);
-          const Vec3vf<K> v2 = tri.getVertex(tri.v2,i,scene);
+          const Vec3vf<K> v0 = tri.template getVertex<0>(i,scene);
+          const Vec3vf<K> v1 = tri.template getVertex<1>(i,scene);
+          const Vec3vf<K> v2 = tri.template getVertex<2>(i,scene);
           pre.intersectK(valid_i,ray,v0,v1,v2,UVIdentity<K>(),IntersectKEpilogM<M,K,filter>(ray,context,tri.geomID(),tri.primID(),i));
         }
       }
@@ -162,9 +149,9 @@ namespace embree
         {
           if (!tri.valid(i)) break;
           STAT3(shadow.trav_prims,1,popcnt(valid_i),RayHitK<K>::size());
-          const Vec3vf<K> v0 = tri.getVertex(tri.v0,i,scene);
-          const Vec3vf<K> v1 = tri.getVertex(tri.v1,i,scene);
-          const Vec3vf<K> v2 = tri.getVertex(tri.v2,i,scene);
+          const Vec3vf<K> v0 = tri.template getVertex<0>(i,scene);
+          const Vec3vf<K> v1 = tri.template getVertex<1>(i,scene);
+          const Vec3vf<K> v2 = tri.template getVertex<2>(i,scene);
           pre.intersectK(valid0,ray,v0,v1,v2,UVIdentity<K>(),OccludedKEpilogM<M,K,filter>(valid0,ray,context,tri.geomID(),tri.primID(),i));
           if (none(valid0)) break;
         }
