@@ -1,22 +1,10 @@
-// ======================================================================== //
-// Copyright 2009-2020 Intel Corporation                                    //
-//                                                                          //
-// Licensed under the Apache License, Version 2.0 (the "License");          //
-// you may not use this file except in compliance with the License.         //
-// You may obtain a copy of the License at                                  //
-//                                                                          //
-//     http://www.apache.org/licenses/LICENSE-2.0                           //
-//                                                                          //
-// Unless required by applicable law or agreed to in writing, software      //
-// distributed under the License is distributed on an "AS IS" BASIS,        //
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. //
-// See the License for the specific language governing permissions and      //
-// limitations under the License.                                           //
-// ======================================================================== //
+// Copyright 2009-2020 Intel Corporation
+// SPDX-License-Identifier: Apache-2.0
 
 #pragma once
 
 #include "../common/default.h"
+#include "../common/scene_curves.h"
 
 namespace embree
 {
@@ -108,7 +96,7 @@ namespace embree
       
       bool hasRoot() const;
       
-      friend std::ostream& operator<<(std::ostream& cout, const LinearBezierCurve& a) {
+      friend embree_ostream operator<<(embree_ostream cout, const LinearBezierCurve& a) {
         return cout << "LinearBezierCurve (" << a.v0 << ", " << a.v1 << ")";
       }
     };
@@ -145,7 +133,7 @@ namespace embree
         return merge(BBox<V>(v0),BBox<V>(v1),BBox<V>(v2));
       }
       
-      friend std::ostream& operator<<(std::ostream& cout, const QuadraticBezierCurve& a) {
+      friend embree_ostream operator<<(embree_ostream cout, const QuadraticBezierCurve& a) {
         return cout << "QuadraticBezierCurve ( (" << a.u.lower << ", " << a.u.upper << "), " << a.v0 << ", " << a.v1 << ", " << a.v2 << ")";
       }
     };
@@ -193,7 +181,7 @@ namespace embree
         return v3-v2;
       }
 
-       __forceinline CubicBezierCurve<float> xfm(const Vertex& dx) const {
+      __forceinline CubicBezierCurve<float> xfm(const Vertex& dx) const {
         return CubicBezierCurve<float>(dot(v0,dx),dot(v1,dx),dot(v2,dx),dot(v3,dx));
       }
       
@@ -223,13 +211,13 @@ namespace embree
         return CubicBezierCurve<Vec3fa>(q0,q1,q2,q3);
       }
 
-      __forceinline CubicBezierCurve<Vec3fa> xfm_pr(const LinearSpace3fa& space, const Vec3fa& p) const
+      __forceinline CubicBezierCurve<Vec3ff> xfm_pr(const LinearSpace3fa& space, const Vec3fa& p) const
       {
-        Vec3fa q0 = xfmVector(space,v0-p); q0.w = v0.w;
-        Vec3fa q1 = xfmVector(space,v1-p); q1.w = v1.w;
-        Vec3fa q2 = xfmVector(space,v2-p); q2.w = v2.w;
-        Vec3fa q3 = xfmVector(space,v3-p); q3.w = v3.w;
-        return CubicBezierCurve<Vec3fa>(q0,q1,q2,q3);
+        const Vec3ff q0(xfmVector(space,(Vec3fa)v0-p), v0.w);
+        const Vec3ff q1(xfmVector(space,(Vec3fa)v1-p), v1.w);
+        const Vec3ff q2(xfmVector(space,(Vec3fa)v2-p), v2.w);
+        const Vec3ff q3(xfmVector(space,(Vec3fa)v3-p), v3.w);
+        return CubicBezierCurve<Vec3ff>(q0,q1,q2,q3);
       }
 
       __forceinline CubicBezierCurve<Vec3fa> xfm(const LinearSpace3fa& space, const Vec3fa& p, const float s) const
@@ -491,48 +479,48 @@ namespace embree
         dp = vfloat<M>(3.0f)*(p21-p20);
       }
       
-      template<int M>
-      __forceinline Vec4vf<M> eval0(const int ofs, const int size) const
+      template<int M, typename Vec = Vec4vf<M>>
+      __forceinline Vec eval0(const int ofs, const int size) const
       {
         assert(size <= PrecomputedBezierBasis::N);
         assert(ofs <= size);
-        return madd(vfloat<M>::loadu(&bezier_basis0.c0[size][ofs]), Vec4vf<M>(v0),
-                    madd(vfloat<M>::loadu(&bezier_basis0.c1[size][ofs]), Vec4vf<M>(v1),
-                         madd(vfloat<M>::loadu(&bezier_basis0.c2[size][ofs]), Vec4vf<M>(v2),
-                              vfloat<M>::loadu(&bezier_basis0.c3[size][ofs]) * Vec4vf<M>(v3))));
+        return madd(vfloat<M>::loadu(&bezier_basis0.c0[size][ofs]), Vec(v0),
+                    madd(vfloat<M>::loadu(&bezier_basis0.c1[size][ofs]), Vec(v1),
+                         madd(vfloat<M>::loadu(&bezier_basis0.c2[size][ofs]), Vec(v2),
+                              vfloat<M>::loadu(&bezier_basis0.c3[size][ofs]) * Vec(v3))));
       }
       
-      template<int M>
-      __forceinline Vec4vf<M> eval1(const int ofs, const int size) const
+      template<int M, typename Vec = Vec4vf<M>>
+      __forceinline Vec eval1(const int ofs, const int size) const
       {
         assert(size <= PrecomputedBezierBasis::N);
         assert(ofs <= size);
-        return madd(vfloat<M>::loadu(&bezier_basis1.c0[size][ofs]), Vec4vf<M>(v0), 
-                    madd(vfloat<M>::loadu(&bezier_basis1.c1[size][ofs]), Vec4vf<M>(v1),
-                         madd(vfloat<M>::loadu(&bezier_basis1.c2[size][ofs]), Vec4vf<M>(v2),
-                              vfloat<M>::loadu(&bezier_basis1.c3[size][ofs]) * Vec4vf<M>(v3))));
+        return madd(vfloat<M>::loadu(&bezier_basis1.c0[size][ofs]), Vec(v0), 
+                    madd(vfloat<M>::loadu(&bezier_basis1.c1[size][ofs]), Vec(v1),
+                         madd(vfloat<M>::loadu(&bezier_basis1.c2[size][ofs]), Vec(v2),
+                              vfloat<M>::loadu(&bezier_basis1.c3[size][ofs]) * Vec(v3))));
       }
       
-      template<int M>
-      __forceinline Vec4vf<M> derivative0(const int ofs, const int size) const
+      template<int M, typename Vec = Vec4vf<M>>
+      __forceinline Vec derivative0(const int ofs, const int size) const
       {
         assert(size <= PrecomputedBezierBasis::N);
         assert(ofs <= size);
-        return madd(vfloat<M>::loadu(&bezier_basis0.d0[size][ofs]), Vec4vf<M>(v0),
-                    madd(vfloat<M>::loadu(&bezier_basis0.d1[size][ofs]), Vec4vf<M>(v1),
-                         madd(vfloat<M>::loadu(&bezier_basis0.d2[size][ofs]), Vec4vf<M>(v2),
-                              vfloat<M>::loadu(&bezier_basis0.d3[size][ofs]) * Vec4vf<M>(v3))));
+        return madd(vfloat<M>::loadu(&bezier_basis0.d0[size][ofs]), Vec(v0),
+                    madd(vfloat<M>::loadu(&bezier_basis0.d1[size][ofs]), Vec(v1),
+                         madd(vfloat<M>::loadu(&bezier_basis0.d2[size][ofs]), Vec(v2),
+                              vfloat<M>::loadu(&bezier_basis0.d3[size][ofs]) * Vec(v3))));
       }
       
-      template<int M>
-      __forceinline Vec4vf<M> derivative1(const int ofs, const int size) const
+      template<int M, typename Vec = Vec4vf<M>>
+      __forceinline Vec derivative1(const int ofs, const int size) const
       {
         assert(size <= PrecomputedBezierBasis::N);
         assert(ofs <= size);
-        return madd(vfloat<M>::loadu(&bezier_basis1.d0[size][ofs]), Vec4vf<M>(v0),
-                    madd(vfloat<M>::loadu(&bezier_basis1.d1[size][ofs]), Vec4vf<M>(v1),
-                         madd(vfloat<M>::loadu(&bezier_basis1.d2[size][ofs]), Vec4vf<M>(v2),
-                              vfloat<M>::loadu(&bezier_basis1.d3[size][ofs]) * Vec4vf<M>(v3))));
+        return madd(vfloat<M>::loadu(&bezier_basis1.d0[size][ofs]), Vec(v0),
+                    madd(vfloat<M>::loadu(&bezier_basis1.d1[size][ofs]), Vec(v1),
+                         madd(vfloat<M>::loadu(&bezier_basis1.d2[size][ofs]), Vec(v2),
+                              vfloat<M>::loadu(&bezier_basis1.d3[size][ofs]) * Vec(v3))));
       }
 
       /* calculates bounds of bezier curve geometry */
@@ -540,15 +528,15 @@ namespace embree
       {
         const int N = 7;
         const float scale = 1.0f/(3.0f*(N-1));
-        Vec4vfx pl(pos_inf), pu(neg_inf);
+        Vec3vfx pl(pos_inf), pu(neg_inf);
         for (int i=0; i<=N; i+=VSIZEX)
         {
           vintx vi = vintx(i)+vintx(step);
           vboolx valid = vi <= vintx(N);
-          const Vec4vfx p  = eval0<VSIZEX>(i,N);
-          const Vec4vfx dp = derivative0<VSIZEX>(i,N);
-          const Vec4vfx pm = p-Vec4vfx(scale)*select(vi!=vintx(0),dp,Vec4vfx(zero));
-          const Vec4vfx pp = p+Vec4vfx(scale)*select(vi!=vintx(N),dp,Vec4vfx(zero));
+          const Vec3vfx p  = eval0<VSIZEX,Vec3vf<VSIZEX>>(i,N);
+          const Vec3vfx dp = derivative0<VSIZEX,Vec3vf<VSIZEX>>(i,N);
+          const Vec3vfx pm = p-Vec3vfx(scale)*select(vi!=vintx(0),dp,Vec3vfx(zero));
+          const Vec3vfx pp = p+Vec3vfx(scale)*select(vi!=vintx(N),dp,Vec3vfx(zero));
           pl = select(valid,min(pl,p,pm,pp),pl); // FIXME: use masked min
           pu = select(valid,max(pu,p,pm,pp),pu); // FIXME: use masked min
         }
@@ -618,7 +606,7 @@ namespace embree
         }
       }
       
-      friend inline std::ostream& operator<<(std::ostream& cout, const CubicBezierCurve& curve) {
+      friend __forceinline embree_ostream operator<<(embree_ostream cout, const CubicBezierCurve& curve) {
         return cout << "CubicBezierCurve { v0 = " << curve.v0 << ", v1 = " << curve.v1 << ", v2 = " << curve.v2 << ", v3 = " << curve.v3 << " }";
       }
     };
@@ -657,7 +645,7 @@ namespace embree
   typedef CubicBezierCurve<Vec3fa> CubicBezierCurve3fa;
   typedef CubicBezierCurve<Vec3fa> BezierCurve3fa;
   
-  template<> inline int CubicBezierCurve<float>::maxRoots() const
+  template<> __forceinline int CubicBezierCurve<float>::maxRoots() const
   {
     float eps = 1E-4f;
     bool neg0 = v0 <= 0.0f; bool zero0 = fabs(v0) < eps;
@@ -670,4 +658,12 @@ namespace embree
   template<> __forceinline int CubicBezierCurve<Interval1f>::maxRoots() const {
     return numRoots(v0,v1) + numRoots(v1,v2) + numRoots(v2,v3);
   }
+
+  __forceinline CubicBezierCurve<Vec3ff> enlargeRadiusToMinWidth(const IntersectContext* context, const CurveGeometry* geom, const Vec3fa& ray_org, const CubicBezierCurve<Vec3ff>& curve)
+  {
+    return CubicBezierCurve<Vec3ff>(enlargeRadiusToMinWidth(context,geom,ray_org,curve.v0),
+                                    enlargeRadiusToMinWidth(context,geom,ray_org,curve.v1),
+                                    enlargeRadiusToMinWidth(context,geom,ray_org,curve.v2),
+                                    enlargeRadiusToMinWidth(context,geom,ray_org,curve.v3));
+  }
 }
