@@ -1,18 +1,5 @@
-// ======================================================================== //
-// Copyright 2009-2020 Intel Corporation                                    //
-//                                                                          //
-// Licensed under the Apache License, Version 2.0 (the "License");          //
-// you may not use this file except in compliance with the License.         //
-// You may obtain a copy of the License at                                  //
-//                                                                          //
-//     http://www.apache.org/licenses/LICENSE-2.0                           //
-//                                                                          //
-// Unless required by applicable law or agreed to in writing, software      //
-// distributed under the License is distributed on an "AS IS" BASIS,        //
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. //
-// See the License for the specific language governing permissions and      //
-// limitations under the License.                                           //
-// ======================================================================== //
+// Copyright 2009-2020 Intel Corporation
+// SPDX-License-Identifier: Apache-2.0
 
 #pragma once
 
@@ -446,11 +433,11 @@ namespace embree
         }
       }
 
-      friend __forceinline std::ostream& operator<<(std::ostream& o, const BSplinePatchT& p)
+      friend __forceinline embree_ostream operator<<(embree_ostream o, const BSplinePatchT& p)
       {
         for (size_t y=0; y<4; y++)
           for (size_t x=0; x<4; x++)
-            o << "[" << y << "][" << x << "] " << p.v[y][x] << std::endl;
+            o << "[" << y << "][" << x << "] " << p.v[y][x] << embree_endl;
         return o;
       } 
 
