@@ -1,18 +1,5 @@
-// ======================================================================== //
-// Copyright 2009-2020 Intel Corporation                                    //
-//                                                                          //
-// Licensed under the Apache License, Version 2.0 (the "License");          //
-// you may not use this file except in compliance with the License.         //
-// You may obtain a copy of the License at                                  //
-//                                                                          //
-//     http://www.apache.org/licenses/LICENSE-2.0                           //
-//                                                                          //
-// Unless required by applicable law or agreed to in writing, software      //
-// distributed under the License is distributed on an "AS IS" BASIS,        //
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. //
-// See the License for the specific language governing permissions and      //
-// limitations under the License.                                           //
-// ======================================================================== //
+// Copyright 2009-2020 Intel Corporation
+// SPDX-License-Identifier: Apache-2.0
 
 #include "subdivpatch1base.h"
 
@@ -333,8 +320,8 @@ namespace embree
         b.upper.x = reduce_max(bounds_max_x);
         b.upper.y = reduce_max(bounds_max_y);
         b.upper.z = reduce_max(bounds_max_z);
-        b.lower.a = 0;
-        b.upper.a = 0;
+        //b.lower.a = 0;
+        //b.upper.a = 0;
       }
       else
       {
@@ -406,8 +393,8 @@ namespace embree
         b.upper.x = reduce_max(bounds_max[0]);
         b.upper.y = reduce_max(bounds_max[1]);
         b.upper.z = reduce_max(bounds_max[2]);
-        b.lower.a = 0;
-        b.upper.a = 0;
+        //b.lower.a = 0;
+        //b.upper.a = 0;
       }
 
       assert( std::isfinite(b.lower.x) );
