@@ -1,18 +1,5 @@
-// ======================================================================== //
-// Copyright 2009-2020 Intel Corporation                                    //
-//                                                                          //
-// Licensed under the Apache License, Version 2.0 (the "License");          //
-// you may not use this file except in compliance with the License.         //
-// You may obtain a copy of the License at                                  //
-//                                                                          //
-//     http://www.apache.org/licenses/LICENSE-2.0                           //
-//                                                                          //
-// Unless required by applicable law or agreed to in writing, software      //
-// distributed under the License is distributed on an "AS IS" BASIS,        //
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. //
-// See the License for the specific language governing permissions and      //
-// limitations under the License.                                           //
-// ======================================================================== //
+// Copyright 2009-2020 Intel Corporation
+// SPDX-License-Identifier: Apache-2.0
 
 #include "../common/tutorial/tutorial_device.h"
 
@@ -154,9 +141,6 @@ namespace embree
   /* called by the C++ code for initialization */
   extern "C" void device_init (char* cfg)
   {
-    /* set start render mode */
-    renderTile = renderTileStandard;
-
     /* create random bounding boxes */
     const size_t N = 2300000;
     const size_t extraSpace = 1000000;
@@ -192,28 +176,14 @@ namespace embree
     build(RTC_BUILD_QUALITY_HIGH,prims,cfg,extraSpace);
   }
 
-  /* task that renders a single screen tile */
-  void renderTileStandard(int taskIndex, int threadIndex, int* pixels,
+  void renderFrameStandard (int* pixels,
                           const unsigned int width,
                           const unsigned int height,
                           const float time,
-                          const ISPCCamera& camera,
-                          const int numTilesX,
-                          const int numTilesY)
+                          const ISPCCamera& camera)
   {
   }
-
-  /* task that renders a single screen tile */
-  void renderTileTask(int taskIndex, int threadIndex, int* pixels,
-                      const unsigned int width,
-                      const unsigned int height,
-                      const float time,
-                      const ISPCCamera& camera,
-                      const int numTilesX,
-                      const int numTilesY)
-  {
-  }
-
+  
   /* called by the C++ code to render */
   extern "C" void device_render (int* pixels,
                                  const int width,
