@@ -1,18 +1,5 @@
-// ======================================================================== //
-// Copyright 2009-2020 Intel Corporation                                    //
-//                                                                          //
-// Licensed under the Apache License, Version 2.0 (the "License");          //
-// you may not use this file except in compliance with the License.         //
-// You may obtain a copy of the License at                                  //
-//                                                                          //
-//     http://www.apache.org/licenses/LICENSE-2.0                           //
-//                                                                          //
-// Unless required by applicable law or agreed to in writing, software      //
-// distributed under the License is distributed on an "AS IS" BASIS,        //
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. //
-// See the License for the specific language governing permissions and      //
-// limitations under the License.                                           //
-// ======================================================================== //
+// Copyright 2009-2020 Intel Corporation
+// SPDX-License-Identifier: Apache-2.0
 
 #include "image.h"
 #include "../../../common/sys/string.h"
@@ -27,8 +14,8 @@ namespace embree
     /* compare image size */
     const size_t width = image0->width;
     const size_t height = image0->height;
-    if (image1->width != width) return 1;
-    if (image1->height != height) return 1;
+    if (image1->width != width) return inf;
+    if (image1->height != height) return inf;
 
     /* compare both images */
     double diff = 0.0;
