@@ -5,7 +5,7 @@
 
 #include "lights.h"
 #include "../../../include/embree3/rtcore.h"
-RTC_NAMESPACE_OPEN
+RTC_NAMESPACE_USE
 #include "../math/random_sampler.h"
 
 namespace embree
