@@ -1,18 +1,5 @@
-// ======================================================================== //
-// Copyright 2009-2020 Intel Corporation                                    //
-//                                                                          //
-// Licensed under the Apache License, Version 2.0 (the "License");          //
-// you may not use this file except in compliance with the License.         //
-// You may obtain a copy of the License at                                  //
-//                                                                          //
-//     http://www.apache.org/licenses/LICENSE-2.0                           //
-//                                                                          //
-// Unless required by applicable law or agreed to in writing, software      //
-// distributed under the License is distributed on an "AS IS" BASIS,        //
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. //
-// See the License for the specific language governing permissions and      //
-// limitations under the License.                                           //
-// ======================================================================== //
+// Copyright 2009-2020 Intel Corporation
+// SPDX-License-Identifier: Apache-2.0
 
 #include "xml_parser.h"
 
@@ -62,8 +49,11 @@ namespace embree
   }
 
   /*! parse XML tag */
-  Ref<XML> parseXML(Ref<Stream<Token> >& cin)
+  Ref<XML> parseXML(Ref<Stream<Token> >& cin, size_t depth)
   {
+    if (depth > 1024)
+      THROW_RUNTIME_ERROR(cin->peek().Location().str()+": maximal nesting depth reached");
+      
     Ref<XML> xml = new XML;
     xml->loc = cin->peek().Location();
 
@@ -92,7 +82,7 @@ namespace embree
     /* the body also contains children */
     if (cin->peek() == Token::Sym("<")) {
       while (cin->peek() != Token::Sym("</")) {
-        xml->children.push_back(parseXML(cin));
+        xml->children.push_back(parseXML(cin,depth+1));
         parseComments(cin);
       }
     }
@@ -123,7 +113,7 @@ namespace embree
 
     if (hasHeader) parseHeader(cin);
     parseComments(cin);
-    Ref<XML> xml = parseXML(cin);
+    Ref<XML> xml = parseXML(cin,0);
     parseComments(cin);
 
     if (!hasTail)
