@@ -1,18 +1,5 @@
-// ======================================================================== //
-// Copyright 2009-2020 Intel Corporation                                    //
-//                                                                          //
-// Licensed under the Apache License, Version 2.0 (the "License");          //
-// you may not use this file except in compliance with the License.         //
-// You may obtain a copy of the License at                                  //
-//                                                                          //
-//     http://www.apache.org/licenses/LICENSE-2.0                           //
-//                                                                          //
-// Unless required by applicable law or agreed to in writing, software      //
-// distributed under the License is distributed on an "AS IS" BASIS,        //
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. //
-// See the License for the specific language governing permissions and      //
-// limitations under the License.                                           //
-// ======================================================================== //
+// Copyright 2009-2020 Intel Corporation
+// SPDX-License-Identifier: Apache-2.0
 
 #pragma once
 
@@ -63,9 +50,15 @@ namespace embree
       return stream.str();
     }
     
-    AffineSpace3fa camera2world () {
+    AffineSpace3fa camera2world ()
+    {
       AffineSpace3fa local2world = AffineSpace3fa::lookat(from, to, up);
-      if (handedness == RIGHT_HANDED) local2world.l.vx = -local2world.l.vx;
+      if (!(local2world == local2world))
+        throw std::runtime_error("invalid camera specified");
+      
+      if (handedness == RIGHT_HANDED)
+        local2world.l.vx = -local2world.l.vx;
+      
       return local2world;
     }
     AffineSpace3fa world2camera () { return rcp(camera2world()); }
