@@ -1,18 +1,5 @@
-// ======================================================================== //
-// Copyright 2009-2020 Intel Corporation                                    //
-//                                                                          //
-// Licensed under the Apache License, Version 2.0 (the "License");          //
-// you may not use this file except in compliance with the License.         //
-// You may obtain a copy of the License at                                  //
-//                                                                          //
-//     http://www.apache.org/licenses/LICENSE-2.0                           //
-//                                                                          //
-// Unless required by applicable law or agreed to in writing, software      //
-// distributed under the License is distributed on an "AS IS" BASIS,        //
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. //
-// See the License for the specific language governing permissions and      //
-// limitations under the License.                                           //
-// ======================================================================== //
+// Copyright 2009-2020 Intel Corporation
+// SPDX-License-Identifier: Apache-2.0
 
 #pragma once
 
@@ -28,7 +15,7 @@ struct Triangle { int v0, v1, v2; };
 
 /* include embree API */
 #include "../../../include/embree3/rtcore.h"
-RTC_NAMESPACE_OPEN
+RTC_NAMESPACE_USE
 
 /* include optional vector library */
 #include "../math/math.h"
@@ -87,30 +74,14 @@ inline Vec3fa faceforward( const Vec3fa& N, const Vec3fa& I, const Vec3fa& Ng )
 #define GLFW_KEY_F12                301
 #endif
 
-/* standard shading function */
-typedef void (* renderTileFunc)(int taskIndex,
-                                        int threadIndex,
-                                        int* pixels,
-                                        const unsigned int width,
-                                        const unsigned int height,
-                                        const float time,
-                                        const ISPCCamera& camera,
-                                        const int numTilesX,
-                                        const int numTilesY);
-extern "C" renderTileFunc renderTile;
-
 extern "C" void device_key_pressed_default(int key);
 extern "C" void (* key_pressed_handler)(int key);
 
-void renderTileStandard(int taskIndex,
-                        int threadIndex,
-                        int* pixels,
-                        const unsigned int width,
-                        const unsigned int height,
-                        const float time,
-                        const ISPCCamera& camera,
-                        const int numTilesX,
-                        const int numTilesY);
+extern "C" void renderFrameStandard(int* pixels,
+                         const unsigned int width,
+                         const unsigned int height,
+                         const float time,
+                         const ISPCCamera& camera);
 
 unsigned int getNumHWThreads();
 
