@@ -1,5 +1,8 @@
 #!/bin/bash
 
+## Copyright 2009-2020 Intel Corporation
+## SPDX-License-Identifier: Apache-2.0
+
 echo Converting ISPC tutorial $1 to CPP tutorial $2
 cp $1 $2
 
@@ -18,6 +21,7 @@ sed -i.backup  's/ varying//g' $2
 sed -i.backup  's/unmasked //g' $2
 sed -i.backup  's/extern \"C\"/__EXTERN_C/g' $2
 sed -i.backup  's/extern/extern \"C\"/g' $2
+sed -i.backup  's/typedef export/typedef/g' $2
 sed -i.backup  's/export/extern \"C\"/g' $2
 sed -i.backup  's/extern \"C\" RTCScene g_scene/extern RTCScene g_scene/g' $2
 sed -i.backup  's/__EXTERN_C/extern \"C\"/g' $2
@@ -54,10 +58,10 @@ sed -i.backup  's/foreach_tiled[ ]*([ ]*\([a-zA-Z0-9_]*\)[ ]*=[ ]*\([^ \.]*\)[ ]
 sed -i.backup  's/foreach_unique[ ]*([ ]*\([[:alnum:]_]*\)[ ]*in[ ]*\([][[:alnum:]._]*\))/unsigned int \1 = \2;/g' $2
 
 sed -i.backup  's/new[ ]*\([a-zA-Z0-9_]*\)[ ]*\[\([^]]*\)\]/(\1\*) alignedMalloc(\2\*sizeof(\1),16)/g' $2
-sed -i.backup  's/delete[ ]*\[[ ]*\][ ]*\([a-zA-Z0-9_.]*\)/alignedFree(\1)/g' $2
+sed -i.backup  's/delete[ ]*\[[ ]*\][ ]*\([a-zA-Z0-9_.\>\-]*\)/alignedFree(\1)/g' $2
 
 sed -i.backup  's/new[ ]*\([a-zA-Z0-9_]*\)[ ]*;/(\1\*) alignedMalloc(sizeof(\1),16);/g' $2
-sed -i.backup  's/delete[ ]*\([a-zA-Z0-9_]*\)[ ]*;/alignedFree(\1);/g' $2
+sed -i.backup  's/delete[ ]*\([a-zA-Z0-9_\>\-]*\)[ ]*;/alignedFree(\1);/g' $2
 
 # embree ray layout
 sed -i.backup  's/[.]tnear/.tnear()/g' $2
@@ -74,9 +78,9 @@ sed -i.backup 's/atomic_compare_exchange_global/atomic_cmpxchg/g' $2
 sed -i.backup 's/memory_barrier/__memory_barrier/g' $2
 
 # math library
-sed -i.backup  's/Vec3f\([^a]\)/Vec3fa\1/g' $2
-sed -i.backup 's/LinearSpace3f\([^a]\)/LinearSpace3fa\1/g' $2
-sed -i.backup 's/AffineSpace3f\([^a]\)/AffineSpace3fa\1/g' $2
+sed -i.backup  's/Vec3f\([^af_]\)/Vec3fa\1/g' $2
+sed -i.backup 's/LinearSpace3f\([^af]\)/LinearSpace3fa\1/g' $2
+sed -i.backup 's/AffineSpace3f\([^af]\)/AffineSpace3fa\1/g' $2
 
 sed -i.backup  's/ = make_Ray//g' $2
 sed -i.backup 's/make_LinearSpace3fa_scale/LinearSpace3fa::scale/g' $2
@@ -88,7 +92,7 @@ sed -i.backup 's/make_LinearSpace3fa_identity()/LinearSpace3fa(one)/g' $2
 sed -i.backup 's/make_LinearSpace3fa\([^_]\)/LinearSpace3fa\1/g' $2
 sed -i.backup 's/make_Quaternion3f_rotate/Quaternion3f::rotate/g' $2
 
-sed -i.backup  's/M_PI/float(pi)/g' $2
+sed -i.backup  's/M_PI/float(M_PI)/g' $2
 sed -i.backup  's/\*pi\*/\*float(pi)\*/g' $2
 sed -i.backup  's/\*pi\//\*float(pi)\//g' $2
 sed -i.backup  's/one_over_pi/float(one_over_pi)/g' $2
@@ -96,13 +100,16 @@ sed -i.backup  's/one_over_two_pi/float(one_over_two_pi)/g' $2
 sed -i.backup  's/one_over_four_pi/float(one_over_four_pi)/g' $2
 sed -i.backup  's/(two_pi/(float(two_pi)/g' $2
 sed -i.backup  's/[^_(]two_pi/float(two_pi)/g' $2
+sed -i.backup  's/make_Vec3f_/Vec3ff/g' $2
+sed -i.backup  's/make_Vec3ff/Vec3ff/g' $2
+sed -i.backup  's/make_Vec3fa/Vec3fa/g' $2
 sed -i.backup  's/make_Vec2f/Vec2f/g' $2
 sed -i.backup  's/make_Vec2i/Vec2i/g' $2
 sed -i.backup  's/make_Vec3f/Vec3f/g' $2
-sed -i.backup  's/make_Vec3fa/Vec3fa/g' $2
 sed -i.backup  's/make_Vec4f/Vec4f/g' $2
 #sed -i.backup  's/make_Sample3f/Sample3f/g' $2
 sed -i.backup  's/make_AffineSpace3f/AffineSpace3f/g' $2
+sed -i.backup  's/Vec3f_\([^af]\)/Vec3ff\1/g' $2
 
 sed -i.backup  's/make_Quaternion3f/Quaternion3f/g' $2
 sed -i.backup  's/make_AffineSpace3f/AffineSpace3f/g' $2
@@ -144,6 +151,8 @@ sed -i.backup 's/const Vec3fa defaultValue/const Vec3fa\& defaultValue/g' $2
 # to make static analysis happy
 sed -i.backup 's/if (all(1 == 0)) continue;//g' $2
 
+sed -i.backup  's/^RENDER_FRAME_FUNCTION_ISPC/RENDER_FRAME_FUNCTION_CPP/g' $2
+
 # add Embree namespace
 ln=`grep -n -E "#include|#pragma" $2 | tail -1 | cut -d: -f1`
 mv $2 $2.backup
