@@ -1,36 +1,14 @@
-// ======================================================================== //
-// Copyright 2009-2020 Intel Corporation                                    //
-//                                                                          //
-// Licensed under the Apache License, Version 2.0 (the "License");          //
-// you may not use this file except in compliance with the License.         //
-// You may obtain a copy of the License at                                  //
-//                                                                          //
-//     http://www.apache.org/licenses/LICENSE-2.0                           //
-//                                                                          //
-// Unless required by applicable law or agreed to in writing, software      //
-// distributed under the License is distributed on an "AS IS" BASIS,        //
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. //
-// See the License for the specific language governing permissions and      //
-// limitations under the License.                                           //
-// ======================================================================== //
+// Copyright 2009-2020 Intel Corporation
+// SPDX-License-Identifier: Apache-2.0
 
-#include "../common/tutorial/tutorial_device.h"
+#include "motion_blur_geometry_device.h"
 
 namespace embree {
 
 /* scene data */
 RTCScene g_scene = nullptr;
-Vec3fa face_colors[12];
+TutorialData data;
 
-/* accumulation buffer */
-Vec3fa* g_accu = nullptr;
-unsigned int g_accu_width = 0;
-unsigned int g_accu_height = 0;
-unsigned int g_accu_count = 0;
-Vec3fa g_accu_vx;
-Vec3fa g_accu_vy;
-Vec3fa g_accu_vz;
-Vec3fa g_accu_p;
 extern "C" bool g_changed;
 extern "C" float g_time;
 extern "C" unsigned int g_num_time_steps;
@@ -102,9 +80,9 @@ unsigned int addSphere(RTCScene scene, const Vec3fa& pos, RTCGeometryType type,
   for (unsigned int t = 0; t < num_time_steps; t++)
   {
     RTCBufferType bufType = RTC_BUFFER_TYPE_VERTEX;
-    Vec3fa *vertex = (Vec3fa*)rtcSetNewGeometryBuffer(geom, bufType, t, RTC_FORMAT_FLOAT4, sizeof(Vec3fa), 1);
-    AffineSpace3fa rotation = AffineSpace3fa::rotate(Vec3fa(0,0,0), Vec3fa(0,1,0), 2.0f*float(pi)*(float)t/(float)(num_time_steps-1));
-    *vertex = Vec3fa(xfmPoint(rotation, Vec3fa(1, 0, 0)) + pos);
+    Vec3ff *vertex = (Vec3ff*)rtcSetNewGeometryBuffer(geom, bufType, t, RTC_FORMAT_FLOAT4, sizeof(Vec3ff), 1);
+    AffineSpace3fa rotation = AffineSpace3fa::rotate(Vec3fa(0,0,0), Vec3fa(0,1,0), 2.0f*float(M_PI)*(float)t/(float)(num_time_steps-1));
+    *vertex = Vec3ff(xfmPoint(rotation, Vec3fa(1, 0, 0)) + pos);
     vertex->w = 1.f;
 
     if (type == RTC_GEOMETRY_TYPE_ORIENTED_DISC_POINT) {
@@ -133,7 +111,7 @@ unsigned int addTriangleCube (RTCScene scene, const Vec3fa& pos, unsigned int nu
     RTCBufferType bufType = RTC_BUFFER_TYPE_VERTEX;
     Vec3fa* vertices = (Vec3fa*) rtcSetNewGeometryBuffer(geom,bufType,t,RTC_FORMAT_FLOAT3,sizeof(Vec3fa), 8);
 
-    AffineSpace3fa rotation = AffineSpace3fa::rotate(Vec3fa(0,0,0),Vec3fa(0,1,0),2.0f*float(pi)*(float)t/(float)(num_time_steps-1));
+    AffineSpace3fa rotation = AffineSpace3fa::rotate(Vec3fa(0,0,0),Vec3fa(0,1,0),2.0f*float(M_PI)*(float)t/(float)(num_time_steps-1));
     AffineSpace3fa scale = AffineSpace3fa::scale(Vec3fa(2.0f,1.0f,1.0f));
 
     for (int i=0; i<8; i++) {
@@ -143,18 +121,18 @@ unsigned int addTriangleCube (RTCScene scene, const Vec3fa& pos, unsigned int nu
   }
 
   /* create face color array */
-  face_colors[0] = Vec3fa(1,0,0);
-  face_colors[1] = Vec3fa(1,0,0);
-  face_colors[2] = Vec3fa(0,1,0);
-  face_colors[3] = Vec3fa(0,1,0);
-  face_colors[4] = Vec3fa(0.5f);
-  face_colors[5] = Vec3fa(0.5f);
-  face_colors[6] = Vec3fa(1.0f);
-  face_colors[7] = Vec3fa(1.0f);
-  face_colors[8] = Vec3fa(0,0,1);
-  face_colors[9] = Vec3fa(0,0,1);
-  face_colors[10] = Vec3fa(1,1,0);
-  face_colors[11] = Vec3fa(1,1,0);
+  data.face_colors[0] = Vec3fa(1,0,0);
+  data.face_colors[1] = Vec3fa(1,0,0);
+  data.face_colors[2] = Vec3fa(0,1,0);
+  data.face_colors[3] = Vec3fa(0,1,0);
+  data.face_colors[4] = Vec3fa(0.5f);
+  data.face_colors[5] = Vec3fa(0.5f);
+  data.face_colors[6] = Vec3fa(1.0f);
+  data.face_colors[7] = Vec3fa(1.0f);
+  data.face_colors[8] = Vec3fa(0,0,1);
+  data.face_colors[9] = Vec3fa(0,0,1);
+  data.face_colors[10] = Vec3fa(1,1,0);
+  data.face_colors[11] = Vec3fa(1,1,0);
 
   rtcCommitGeometry(geom);
   unsigned int geomID = rtcAttachGeometry(scene,geom);
@@ -175,7 +153,7 @@ unsigned int addQuadCube (RTCScene scene, const Vec3fa& pos, unsigned int num_ti
     RTCBufferType bufType = RTC_BUFFER_TYPE_VERTEX;
     Vec3fa* vertices = (Vec3fa*) rtcSetNewGeometryBuffer(geom,bufType,t,RTC_FORMAT_FLOAT3,sizeof(Vec3fa), 8);
 
-    AffineSpace3fa rotation = AffineSpace3fa::rotate(Vec3fa(0,0,0),Vec3fa(0,1,0),2.0f*float(pi)*(float)t/(float)(num_time_steps-1));
+    AffineSpace3fa rotation = AffineSpace3fa::rotate(Vec3fa(0,0,0),Vec3fa(0,1,0),2.0f*float(M_PI)*(float)t/(float)(num_time_steps-1));
     AffineSpace3fa scale = AffineSpace3fa::scale(Vec3fa(2.0f,1.0f,1.0f));
 
     for (int i=0; i<8; i++) {
@@ -215,7 +193,7 @@ unsigned int addSubdivCube (RTCScene scene, const Vec3fa& pos, unsigned int num_
     RTCBufferType bufType = RTC_BUFFER_TYPE_VERTEX;
     Vec3fa* vertices = (Vec3fa*) rtcSetNewGeometryBuffer(geom,bufType,t,RTC_FORMAT_FLOAT3,sizeof(Vec3fa),8);
 
-    AffineSpace3fa rotation = AffineSpace3fa::rotate(Vec3fa(0,0,0),Vec3fa(0,1,0),2.0f*float(pi)*(float)t/(float)(num_time_steps-1));
+    AffineSpace3fa rotation = AffineSpace3fa::rotate(Vec3fa(0,0,0),Vec3fa(0,1,0),2.0f*float(M_PI)*(float)t/(float)(num_time_steps-1));
     AffineSpace3fa scale = AffineSpace3fa::scale(Vec3fa(2.0f,1.0f,1.0f));
 
     for (int i=0; i<8; i++) {
@@ -246,13 +224,13 @@ unsigned int addCurve (RTCScene scene, const Vec3fa& pos, RTCGeometryType type,
   for (unsigned int t=0; t<num_time_steps; t++)
   {
     RTCBufferType bufType = RTC_BUFFER_TYPE_VERTEX;
-    Vec3fa* vertices = (Vec3fa*) rtcSetNewGeometryBuffer(geom,bufType,t,RTC_FORMAT_FLOAT4,sizeof(Vec3fa),16);
+    Vec3ff* vertices = (Vec3ff*) rtcSetNewGeometryBuffer(geom,bufType,t,RTC_FORMAT_FLOAT4,sizeof(Vec3ff),16);
 
-    AffineSpace3fa rotation = AffineSpace3fa::rotate(Vec3fa(0,0,0),Vec3fa(0,1,0),2.0f*float(pi)*(float)t/(float)(num_time_steps-1));
+    AffineSpace3fa rotation = AffineSpace3fa::rotate(Vec3fa(0,0,0),Vec3fa(0,1,0),2.0f*float(M_PI)*(float)t/(float)(num_time_steps-1));
     AffineSpace3fa scale = AffineSpace3fa::scale(Vec3fa(2.0f,1.0f,1.0f));
 
     for (int i=0; i<16; i++)
-      vertices[i] = Vec3fa(xfmPoint(rotation*scale,bspline[i])+pos,0.2f);
+      vertices[i] = Vec3ff(xfmPoint(rotation*scale,bspline[i])+pos,0.2f);
   }
 
   int* indices = (int*) rtcSetNewGeometryBuffer(geom,RTC_BUFFER_TYPE_INDEX,0,RTC_FORMAT_UINT,sizeof(int),13);
@@ -281,13 +259,13 @@ unsigned int addLines (RTCScene scene, const Vec3fa& pos, unsigned int num_time_
   for (unsigned int t=0; t<num_time_steps; t++)
   {
     RTCBufferType bufType = RTC_BUFFER_TYPE_VERTEX;
-    Vec3fa* vertices = (Vec3fa*) rtcSetNewGeometryBuffer(geom,bufType,t,RTC_FORMAT_FLOAT4,sizeof(Vec3fa),16);
+    Vec3ff* vertices = (Vec3ff*) rtcSetNewGeometryBuffer(geom,bufType,t,RTC_FORMAT_FLOAT4,sizeof(Vec3ff),16);
 
-    AffineSpace3fa rotation = AffineSpace3fa::rotate(Vec3fa(0,0,0),Vec3fa(0,1,0),2.0f*float(pi)*(float)t/(float)(num_time_steps-1));
+    AffineSpace3fa rotation = AffineSpace3fa::rotate(Vec3fa(0,0,0),Vec3fa(0,1,0),2.0f*float(M_PI)*(float)t/(float)(num_time_steps-1));
     AffineSpace3fa scale = AffineSpace3fa::scale(Vec3fa(2.0f,1.0f,1.0f));
 
     for (int i=0; i<16; i++)
-      vertices[i] = Vec3fa(xfmPoint(rotation*scale,bspline[i])+pos,0.2f);
+      vertices[i] = Vec3ff(xfmPoint(rotation*scale,bspline[i])+pos,0.2f);
   }
 
   int* indices = (int*) rtcSetNewGeometryBuffer(geom,RTC_BUFFER_TYPE_INDEX,0,RTC_FORMAT_UINT,sizeof(int),15);
@@ -319,7 +297,7 @@ RTCScene addInstancedTriangleCube (RTCScene global_scene, const Vec3fa& pos, uns
   
   for (unsigned int t=0; t<num_time_steps; t++)
   {
-    AffineSpace3fa rotation = AffineSpace3fa::rotate(Vec3fa(0,0,0),Vec3fa(0,1,0),2.0f*float(pi)*(float)t/(float)(num_time_steps-1));
+    AffineSpace3fa rotation = AffineSpace3fa::rotate(Vec3fa(0,0,0),Vec3fa(0,1,0),2.0f*float(M_PI)*(float)t/(float)(num_time_steps-1));
     AffineSpace3fa scale = AffineSpace3fa::scale(Vec3fa(2.0f,1.0f,1.0f));
     AffineSpace3fa translation = AffineSpace3fa::translate(pos);
     AffineSpace3fa xfm = translation*rotation*scale;
@@ -345,7 +323,7 @@ RTCScene addInstancedQuadCube (RTCScene global_scene, const Vec3fa& pos, unsigne
     RTCBufferType bufType = RTC_BUFFER_TYPE_VERTEX;
     Vec3fa* vertices = (Vec3fa*) rtcSetNewGeometryBuffer(geom,bufType,t,RTC_FORMAT_FLOAT3,sizeof(Vec3fa),8);
 
-    AffineSpace3fa rotation = AffineSpace3fa::rotate(Vec3fa(0,0,0),Vec3fa(0,1,0),0.5f*2.0f*float(pi)*(float)t/(float)(num_time_steps-1));
+    AffineSpace3fa rotation = AffineSpace3fa::rotate(Vec3fa(0,0,0),Vec3fa(0,1,0),0.5f*2.0f*float(M_PI)*(float)t/(float)(num_time_steps-1));
     AffineSpace3fa scale = AffineSpace3fa::scale(Vec3fa(2.0f,1.0f,1.0f));
 
     for (int i=0; i<8; i++) {
@@ -365,7 +343,7 @@ RTCScene addInstancedQuadCube (RTCScene global_scene, const Vec3fa& pos, unsigne
 
   for (unsigned int t=0; t<num_time_steps; t++)
   {
-    AffineSpace3fa rotation = AffineSpace3fa::rotate(Vec3fa(0,0,0),Vec3fa(0,1,0),0.5f*2.0f*float(pi)*(float)t/(float)(num_time_steps-1));
+    AffineSpace3fa rotation = AffineSpace3fa::rotate(Vec3fa(0,0,0),Vec3fa(0,1,0),0.5f*2.0f*float(M_PI)*(float)t/(float)(num_time_steps-1));
     AffineSpace3fa translation = AffineSpace3fa::translate(pos);
     AffineSpace3fa xfm = translation*rotation;
     rtcSetGeometryTransform(inst,t,RTC_FORMAT_FLOAT4X4_COLUMN_MAJOR,(float*)&xfm);
@@ -381,22 +359,13 @@ RTCScene addInstancedQuadCube (RTCScene global_scene, const Vec3fa& pos, unsigne
 //                     User defined sphere geometry                         //
 // ======================================================================== //
 
-struct Sphere
-{
-  ALIGNED_STRUCT_(16)
-  Vec3fa p;                      //!< position of the sphere
-  float r;                      //!< radius of the sphere
-  unsigned int geomID;
-  unsigned int num_time_steps;
-};
-
 void sphereBoundsFunc(const struct RTCBoundsFunctionArguments* args)
 {
   const Sphere* spheres = (const Sphere*) args->geometryUserPtr;
   RTCBounds* bounds_o = args->bounds_o;
   const unsigned int time = args->timeStep;
   const Sphere& sphere = spheres[args->primID];
-  float ft = 2.0f*float(pi) * (float) time / (float) (sphere.num_time_steps-1);
+  float ft = 2.0f*float(M_PI) * (float) time / (float) (sphere.num_time_steps-1);
   Vec3fa p = sphere.p + Vec3fa(cos(ft),0.0f,sin(ft));
   bounds_o->lower_x = p.x-sphere.r;
   bounds_o->lower_y = p.y-sphere.r;
@@ -425,8 +394,8 @@ void sphereIntersectFuncN(const RTCIntersectFunctionNArguments* args)
   const float time = ray->time()*(float)(time_segments);
   const int itime = clamp((int)(floor(time)),(int)0,time_segments-1);
   const float ftime = time - (float)(itime);
-  const float ft0 = 2.0f*float(pi) * (float) (itime+0) / (float) (sphere.num_time_steps-1);
-  const float ft1 = 2.0f*float(pi) * (float) (itime+1) / (float) (sphere.num_time_steps-1);
+  const float ft0 = 2.0f*float(M_PI) * (float) (itime+0) / (float) (sphere.num_time_steps-1);
+  const float ft1 = 2.0f*float(M_PI) * (float) (itime+1) / (float) (sphere.num_time_steps-1);
   const Vec3fa p0 = sphere.p + Vec3fa(cos(ft0),0.0f,sin(ft0));
   const Vec3fa p1 = sphere.p + Vec3fa(cos(ft1),0.0f,sin(ft1));
   const Vec3fa sphere_p = (1.0f-ftime)*p0 + ftime*p1;
@@ -477,8 +446,8 @@ void sphereOccludedFuncN(const RTCOccludedFunctionNArguments* args)
   const float time = ray->time()*(float)(time_segments);
   const int itime = clamp((int)(floor(time)),(int)0,time_segments-1);
   const float ftime = time - (float)(itime);
-  const float ft0 = 2.0f*float(pi) * (float) (itime+0) / (float) (sphere.num_time_steps-1);
-  const float ft1 = 2.0f*float(pi) * (float) (itime+1) / (float) (sphere.num_time_steps-1);
+  const float ft0 = 2.0f*float(M_PI) * (float) (itime+0) / (float) (sphere.num_time_steps-1);
+  const float ft1 = 2.0f*float(M_PI) * (float) (itime+1) / (float) (sphere.num_time_steps-1);
   const Vec3fa p0 = sphere.p + Vec3fa(cos(ft0),0.0f,sin(ft0));
   const Vec3fa p1 = sphere.p + Vec3fa(cos(ft1),0.0f,sin(ft1));
   const Vec3fa sphere_p = (1.0f-ftime)*p0 + ftime*p1;
@@ -544,24 +513,13 @@ unsigned int addGroundPlane (RTCScene scene)
   return geomID;
 }
 
-RTCScene scene0 = nullptr;
-RTCScene scene1 = nullptr;
-RTCScene scene2 = nullptr;
-RTCScene scene3 = nullptr;
-Sphere* sphere0 = nullptr;
-Sphere* sphere1 = nullptr;
-
 /* called by the C++ code for initialization */
 extern "C" void device_init (char* cfg)
 {
-  /* initialize last seen camera */
-  g_accu_vx = Vec3fa(0.0f);
-  g_accu_vy = Vec3fa(0.0f);
-  g_accu_vz = Vec3fa(0.0f);
-  g_accu_p  = Vec3fa(0.0f);
-
   /* create scene */
-  g_scene = rtcNewScene(g_device);
+  TutorialData_Constructor(&data);
+  g_scene = data.g_scene = rtcNewScene(g_device);
+  data.g_time = g_time;
 
   /* add geometry to the scene */
   addTriangleCube(g_scene,Vec3fa(-5,1,-5),g_num_time_steps);
@@ -582,14 +540,14 @@ extern "C" void device_init (char* cfg)
   addCurve (g_scene,Vec3fa(+5,1, 0),RTC_GEOMETRY_TYPE_ROUND_BSPLINE_CURVE,g_num_time_steps);
   addCurve (g_scene,Vec3fa(+5,5, 0),RTC_GEOMETRY_TYPE_ROUND_BSPLINE_CURVE,g_num_time_steps2);
 
-  scene0 = addInstancedTriangleCube(g_scene,Vec3fa(-5,1,+5),g_num_time_steps);
-  scene1 = addInstancedTriangleCube(g_scene,Vec3fa(-5,5,+5),g_num_time_steps2);
+  data.scene0 = addInstancedTriangleCube(g_scene,Vec3fa(-5,1,+5),g_num_time_steps);
+  data.scene1 = addInstancedTriangleCube(g_scene,Vec3fa(-5,5,+5),g_num_time_steps2);
 
-  scene2 = addInstancedQuadCube    (g_scene,Vec3fa( 0,1,+5),g_num_time_steps);
-  scene3 = addInstancedQuadCube    (g_scene,Vec3fa( 0,5,+5),g_num_time_steps2);
+  data.scene2 = addInstancedQuadCube    (g_scene,Vec3fa( 0,1,+5),g_num_time_steps);
+  data.scene3 = addInstancedQuadCube    (g_scene,Vec3fa( 0,5,+5),g_num_time_steps2);
 
-  sphere0 = addUserGeometrySphere   (g_scene,Vec3fa(+5,1,+5),1.0f,g_num_time_steps);
-  sphere1 = addUserGeometrySphere   (g_scene,Vec3fa(+5,5,+5),1.0f,g_num_time_steps2);
+  data.sphere0 = addUserGeometrySphere   (g_scene,Vec3fa(+5,1,+5),1.0f,g_num_time_steps);
+  data.sphere1 = addUserGeometrySphere   (g_scene,Vec3fa(+5,5,+5),1.0f,g_num_time_steps2);
 
   addSphere(g_scene, Vec3fa(-5, 1, +10), RTC_GEOMETRY_TYPE_ORIENTED_DISC_POINT, g_num_time_steps);
   addSphere(g_scene, Vec3fa(-5, 5, +10), RTC_GEOMETRY_TYPE_ORIENTED_DISC_POINT, g_num_time_steps2);
@@ -602,22 +560,18 @@ extern "C" void device_init (char* cfg)
 
   /* commit changes to scene */
   rtcCommitScene (g_scene);
-
-  /* set start render mode */
-  renderTile = renderTileStandard;
-  key_pressed_handler = device_key_pressed_default;
 }
 
 int frameID = 50;
 
 /* task that renders a single screen tile */
-Vec3fa renderPixelStandard(float x, float y, const ISPCCamera& camera, RayStats& stats)
+Vec3fa renderPixel(const TutorialData& data, float x, float y, const ISPCCamera& camera, RayStats& stats)
 {
   RTCIntersectContext context;
   rtcInitIntersectContext(&context);
   
   float time = abs((int)(0.01f*frameID) - 0.01f*frameID);
-  if (g_time != -1) time = g_time;
+  if (data.g_time != -1) time = data.g_time;
 
   /* initialize ray */
   Ray ray(Vec3fa(camera.xfm.p), Vec3fa(normalize(x*camera.xfm.l.vx + y*camera.xfm.l.vy + camera.xfm.l.vz)), 0.0f, inf, time);
@@ -634,16 +588,16 @@ Vec3fa renderPixelStandard(float x, float y, const ISPCCamera& camera, RayStats&
     if (ray.instID[0] == RTC_INVALID_GEOMETRY_ID)
       ray.instID[0] = ray.geomID;
     switch (ray.instID[0] / 2) {
-    case 0: diffuse = face_colors[ray.primID]; break;
-    case 1: diffuse = face_colors[2*ray.primID]; break;
-    case 2: diffuse = face_colors[2*ray.primID]; break;
+    case 0: diffuse = data.face_colors[ray.primID]; break;
+    case 1: diffuse = data.face_colors[2*ray.primID]; break;
+    case 2: diffuse = data.face_colors[2*ray.primID]; break;
 
     case 3: diffuse = Vec3fa(0.5f,0.0f,0.0f); break;
     case 4: diffuse = Vec3fa(0.0f,0.5f,0.0f); break;
     case 5: diffuse = Vec3fa(0.0f,0.0f,0.5f); break;
 
-    case 6: diffuse = face_colors[ray.primID]; break;
-    case 7: diffuse = face_colors[2*ray.primID]; break;
+    case 6: diffuse = data.face_colors[ray.primID]; break;
+    case 7: diffuse = data.face_colors[2*ray.primID]; break;
     case 8: diffuse = Vec3fa(0.5f,0.5f,0.0f); break;
     default: diffuse = Vec3fa(0.5f,0.5f,0.5f); break;
     }
@@ -664,6 +618,25 @@ Vec3fa renderPixelStandard(float x, float y, const ISPCCamera& camera, RayStats&
   return color;
 }
 
+void updatePixel(const TutorialData& data, int x, int y,
+                  int* pixels,
+                  const unsigned int width,
+                  const unsigned int height,
+                  const float time,
+                  const ISPCCamera& camera, RayStats& stats)
+{
+  /* calculate pixel color */
+  Vec3fa color = renderPixel(data,(float)x,(float)y,camera,stats);
+  
+  /* write color to framebuffer */
+  Vec3ff accu_color = data.g_accu[y*width+x] + Vec3ff(color.x,color.y,color.z,1.0f); data.g_accu[y*width+x] = accu_color;
+  float f = rcp(max(0.001f,accu_color.w));
+  unsigned int r = (unsigned int) (255.0f * clamp(accu_color.x*f,0.0f,1.0f));
+  unsigned int g = (unsigned int) (255.0f * clamp(accu_color.y*f,0.0f,1.0f));
+  unsigned int b = (unsigned int) (255.0f * clamp(accu_color.z*f,0.0f,1.0f));
+  pixels[y*width+x] = (b << 16) + (g << 8) + r;
+}
+
 /* renders a single screen tile */
 void renderTileStandard(int taskIndex,
                         int threadIndex,
@@ -684,16 +657,7 @@ void renderTileStandard(int taskIndex,
 
   for (unsigned int y=y0; y<y1; y++) for (unsigned int x=x0; x<x1; x++)
   {
-    /* calculate pixel color */
-    Vec3fa color = renderPixelStandard((float)x,(float)y,camera,g_stats[threadIndex]);
-
-    /* write color to framebuffer */
-    Vec3fa accu_color = g_accu[y*width+x] + Vec3fa(color.x,color.y,color.z,1.0f); g_accu[y*width+x] = accu_color;
-    float f = rcp(max(0.001f,accu_color.w));
-    unsigned int r = (unsigned int) (255.0f * clamp(accu_color.x*f,0.0f,1.0f));
-    unsigned int g = (unsigned int) (255.0f * clamp(accu_color.y*f,0.0f,1.0f));
-    unsigned int b = (unsigned int) (255.0f * clamp(accu_color.z*f,0.0f,1.0f));
-    pixels[y*width+x] = (b << 16) + (g << 8) + r;
+    updatePixel(data,(float)x,(float)y,pixels,width,height,time,camera,g_stats[threadIndex]);
   }
 }
 
@@ -706,7 +670,23 @@ void renderTileTask (int taskIndex, int threadIndex, int* pixels,
                          const int numTilesX,
                          const int numTilesY)
 {
-  renderTile(taskIndex,threadIndex,pixels,width,height,time,camera,numTilesX,numTilesY);
+  renderTileStandard(taskIndex,threadIndex,pixels,width,height,time,camera,numTilesX,numTilesY);
+}
+
+extern "C" void renderFrameStandard (int* pixels,
+                          const unsigned int width,
+                          const unsigned int height,
+                          const float time,
+                          const ISPCCamera& camera)
+{
+  /* render next frame */
+  const int numTilesX = (width +TILE_SIZE_X-1)/TILE_SIZE_X;
+  const int numTilesY = (height+TILE_SIZE_Y-1)/TILE_SIZE_Y;
+  parallel_for(size_t(0),size_t(numTilesX*numTilesY),[&](const range<size_t>& range) {
+    const int threadIndex = (int)TaskScheduler::threadIndex();
+    for (size_t i=range.begin(); i<range.end(); i++)
+      renderTileTask((int)i,threadIndex,pixels,width,height,time,camera,numTilesX,numTilesY);
+  }); 
 }
 
 /* called by the C++ code to render */
@@ -717,53 +697,36 @@ extern "C" void device_render (int* pixels,
                            const ISPCCamera& camera)
 {
   /* create accumulator */
-  if (g_accu_width != width || g_accu_height != height) {
-    alignedFree(g_accu);
-    g_accu = (Vec3fa*) alignedMalloc(width*height*sizeof(Vec3fa),16);
-    g_accu_width = width;
-    g_accu_height = height;
+  if (data.g_accu_width != width || data.g_accu_height != height) {
+    alignedFree(data.g_accu);
+    data.g_accu = (Vec3ff*) alignedMalloc(width*height*sizeof(Vec3ff),16);
+    data.g_accu_width = width;
+    data.g_accu_height = height;
     for (unsigned int i=0; i<width*height; i++)
-      g_accu[i] = Vec3fa(0.0f);
+      data.g_accu[i] = Vec3ff(0.0f);
   }
 
   /* reset accumulator */
   bool camera_changed = g_changed; g_changed = false;
-  camera_changed |= ne(g_accu_vx,camera.xfm.l.vx); g_accu_vx = camera.xfm.l.vx;
-  camera_changed |= ne(g_accu_vy,camera.xfm.l.vy); g_accu_vy = camera.xfm.l.vy;
-  camera_changed |= ne(g_accu_vz,camera.xfm.l.vz); g_accu_vz = camera.xfm.l.vz;
-  camera_changed |= ne(g_accu_p, camera.xfm.p);    g_accu_p  = camera.xfm.p;
+  camera_changed |= ne(data.g_accu_vx,camera.xfm.l.vx); data.g_accu_vx = camera.xfm.l.vx;
+  camera_changed |= ne(data.g_accu_vy,camera.xfm.l.vy); data.g_accu_vy = camera.xfm.l.vy;
+  camera_changed |= ne(data.g_accu_vz,camera.xfm.l.vz); data.g_accu_vz = camera.xfm.l.vz;
+  camera_changed |= ne(data.g_accu_p, camera.xfm.p);    data.g_accu_p  = camera.xfm.p;
   //camera_changed = true;
   if (camera_changed) {
-    g_accu_count=0;
+    data.g_accu_count=0;
     for (unsigned int i=0; i<width*height; i++)
-      g_accu[i] = Vec3fa(0.0f);
+      data.g_accu[i] = Vec3ff(0.0f);
   }
 
   /* render next frame */
   frameID++;
-  const int numTilesX = (width +TILE_SIZE_X-1)/TILE_SIZE_X;
-  const int numTilesY = (height+TILE_SIZE_Y-1)/TILE_SIZE_Y;
-  parallel_for(size_t(0),size_t(numTilesX*numTilesY),[&](const range<size_t>& range) {
-    const int threadIndex = (int)TaskScheduler::threadIndex();
-    for (size_t i=range.begin(); i<range.end(); i++)
-      renderTileTask((int)i,threadIndex,pixels,width,height,time,camera,numTilesX,numTilesY);
-  }); 
 }
 
 /* called by the C++ code for cleanup */
 extern "C" void device_cleanup ()
 {
-  alignedFree(sphere0); sphere0 = nullptr;
-  alignedFree(sphere1); sphere1 = nullptr;
-  rtcReleaseScene(scene0); scene0 = nullptr;
-  rtcReleaseScene(scene1); scene1 = nullptr;
-  rtcReleaseScene(scene2); scene2 = nullptr;
-  rtcReleaseScene(scene3); scene3 = nullptr;
-  rtcReleaseScene (g_scene); g_scene = nullptr;
-  alignedFree(g_accu); g_accu = nullptr;
-  g_accu_width = 0;
-  g_accu_height = 0;
-  g_accu_count = 0;
+  TutorialData_Destructor(&data);
 }
 
 } // namespace embree
