@@ -1,24 +1,11 @@
-// ======================================================================== //
-// Copyright 2009-2020 Intel Corporation                                    //
-//                                                                          //
-// Licensed under the Apache License, Version 2.0 (the "License");          //
-// you may not use this file except in compliance with the License.         //
-// You may obtain a copy of the License at                                  //
-//                                                                          //
-//     http://www.apache.org/licenses/LICENSE-2.0                           //
-//                                                                          //
-// Unless required by applicable law or agreed to in writing, software      //
-// distributed under the License is distributed on an "AS IS" BASIS,        //
-// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. //
-// See the License for the specific language governing permissions and      //
-// limitations under the License.                                           //
-// ======================================================================== //
+// Copyright 2009-2020 Intel Corporation
+// SPDX-License-Identifier: Apache-2.0
 
 /* we include the Embree headers the very first to make sure they
  * always compile without any internal Embree specific stuff. */
 #include "../../include/embree3/rtcore.h"
 #include "../../include/embree3/rtcore_ray.h"
-RTC_NAMESPACE_OPEN
+RTC_NAMESPACE_USE
 
 /* now we include all Embree internal files we need for testing */
 #include "../../kernels/common/default.h"
